<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\Admin\AdminLoginRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use App\Repository\Eloquent\ContentRepository;
use App\Http\Requests\ContactRequest;
use Exception;

class AdminAuthController extends Controller
{
    protected $contentRepository;
    public function __construct(ContentRepository $contentRepository)
    {
    //     $this->adminrepository = $adminrepository;
        $this->contentRepository = $contentRepository;
    }
    //
    public function showLoginForm()
    {
        
        try {
            return view('admin.login');
        } catch (Exception $e) {
            Log::error("AdminAuthController : showLoginForm()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.login')->withErrors(['error' => __('message.something_went_wrong')]);

        }
    }


    public function login(AdminLoginRequest $request)
    {
        
        try {
            $credentials = $request->only('email', 'password');
          
            if (Auth::guard('admin')->attempt($credentials)) {
                return redirect()->route('admin.dashboard');

            }
            // dd('dfdjfbgd');
            // Authentication failed
            return redirect()->back()->withErrors([
                'email' => __('message.statusInvalid'),
            ])->withInput();

        } catch (Exception $e) {
            Log::error("AdminAuthController : login()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.login')->withErrors(['error' => __('message.something_went_wrong')]);

        }
    }
    public function logout()
    {
        try {
            Auth::guard('admin')->logout();
            return redirect()->route('admin.login');
        } catch (Exception $e) {
            Log::error("AdminAuthController : logout()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.login')->withErrors(['error' => __('message.something_went_wrong')]);

        }
    }

    public function privacy()
    {
        try {
         // dd('sdfdhjsgf');
            $data = $this->contentRepository->getOne(['title'=>'privacy']);
            return view('admin.privacy',compact('data'));
        } catch (Exception $e) {
            Log::error("AdminAuthController : privacy()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.login')->withErrors(['error' => __('message.something_went_wrong')]);

        }   
    }

    public function contactUs()
    {
        try {
         
            return view('admin.contact-us');
        } catch (Exception $e) {
            Log::error("AdminAuthController : privacy()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.login')->withErrors(['error' => __('message.something_went_wrong')]);

        }   
    }

    public function contactStore(ContactRequest $request)
    {
        try {
            $data = $request->all();

        

            $result = $this->contentRepository->createContact($data);

            if ($result) {
                return response()->json([
                    'message' => __('Contact submit successfully'),
                    'data' => $data,
                    'status' => 1,
                ], 201);
            } else {
                return response()->json(['status' => 0, 'message' => 'Failed to save contact form data.', 'error' => []], 500);
            }
        } catch (\Exception $e) {
            // Log the error and return a failure response
            Log::error('Error in AdminAuthController/contactStore: ' . $e->getMessage() . ' in line ' . $e->getLine());
            return response()->json([
                'status' => 0,
                'message' => __('message.statusZero'),
                'data' => [],
                'error' => []
            ], 500);
        }
    }
    
}
