<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Repository\Eloquent\CategoryRepository;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Exception;
use Illuminate\Support\Facades\Redis;
use App\Http\Requests\Admin\CategoryRequest;
use App\Traits\UploadImageTrait;
use Illuminate\Support\Facades\File;


class CategoryController extends Controller
{
    use UploadImageTrait;
    protected $CategoryRepository;

    public function __construct(CategoryRepository $CategoryRepository)
    {
        $this->CategoryRepository = $CategoryRepository;
        // $this->appsettingrepository = $appsettingrepository;
    }

    public function get()
    {
        $data = $this->CategoryRepository->getAll();
        // dd($data);
        return view('admin.category', compact('data'));
    }

    public function add(CategoryRequest $request)
    {
        try {
            
            $data['name_en'] = $request->name_en;
            $data['name_ar'] = $request->name_ar;
            $success = $this->CategoryRepository->create($data);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusOne', ['parameter' => 'Category'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("CategoryController : add()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function update(CategoryRequest $request, $id)
    {
        // dd($request);
        try {
            $data = $this->CategoryRepository->getOne(['id' => $id]);

            $value['name_en'] = $request->name_en;
            $value['name_ar'] = $request->name_ar;

            $success = $this->CategoryRepository->update(['id' => $id], $value);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusTwo', ['parameter' => 'Category'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("CategoryController : update()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function delete(Request $request, $id)
    {
        try {

            $success = $this->CategoryRepository->delete(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusThree', ['parameter' => 'Category'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("CategoryController : TypeDelete()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function show($id)
    {
        try {

            $success = $this->CategoryRepository->getOne(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'data' => $success, 'message' => __('message.statusThree', ['parameter' => 'Category'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("CategoryController : show()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }
}
