<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
// use App\Repository\Eloquent\AdminRepository;
use App\Repository\Eloquent\ContentRepository;
use Illuminate\Support\Facades\Log;
use App\Http\Requests\Admin\ContentRequest;
use App\Http\Requests\Admin\FaqRequest;
use Yajra\DataTables\Facades\DataTables;
use App\Services\Admin\AdminServices;
use App\Models\User;
use App\Models\Restaurant;

class DashboardController extends Controller
{
    //
    // protected $adminrepository;
    protected $contentRepository;
    protected $adminServices;

    public function __construct(ContentRepository $contentRepository,AdminServices $adminServices)
    {
    //     $this->adminrepository = $adminrepository;
        $this->contentRepository = $contentRepository;
        $this->adminServices = $adminServices;
    }

    public function index()
    {
        // $userCount = User::count();
        // $resturantCount = Restaurant::count();

        return view('admin.dashboard'); // Ensure this view file exists
    }

    public function contactusList(Request $request)
    {
        try {

            if ($request->ajax()) {

                $data  =  $this->contentRepository->getContact();

                return Datatables::of($data)
                    ->editColumn('userId', function ($row) {
                        $userId = isset($row->user->first_name) ? $row->user->first_name : '';
                        return $userId;
                    })
                    ->editColumn('email', function ($row) {
                        $email = isset($row->email) ? $row->email : '';
                        return $email;
                    })
                    ->editColumn('message', function ($row) {
                        $message = isset($row->message) ?  substr($row->message, 0, 100) . '.....' : '';
                        return $message;
                    })
                    ->editColumn('created_at', function ($row) {
                        return date('d-m-Y', strtotime($row->created_at));
                    })
                    // ->editColumn('screen_shot', function ($row) {
                    //     $url = asset('storage/' .  json_decode($row->screen_shot));
                    //     return '<a href="' . $url . '" data-lightbox="preview-images.'.$row->id.'" data-title="Screenshot">' .
                    //         '<img src="' . $url . '" border="0" width="40" class="img-rounded" align="center" />' .
                    //         '</a>';
                    // })

                    ->editColumn('screen_shot', function ($row) {
                        $imagePaths = json_decode($row->screen_shot, true);
                        if (is_array($imagePaths) && !empty($imagePaths)) {
                            $links = '';
                            foreach ($imagePaths as $path) {
                                $url = asset('storage/' . $path);
                                $links .= '<a href="' . $url . '" data-lightbox="preview-images.' . $row->id . '" data-title="Screenshot">' .
                                    '<img src="' . $url . '" border="0" width="40" class="img-rounded" align="center" />' .
                                    '</a> ';
                            }

                            return $links;
                        }
                        return 'No screenshot is uploaded';
                    })
                    ->addColumn('sn', function ($timeTable) {
                        static $i = 0;
                        $i++;
                        return $i;
                    })
                    ->addColumn('action', function ($row) {
                        $viewBtn = ' <button href="javascript:void(0)" class="btn btn-primary btn-sm"  onclick="return getContactData(' . $row->id . ')">
                                        View
                                    </button>';
                        return  $viewBtn;
                    })
                    ->rawColumns(['action', 'userId', 'email', 'message', 'created_at', 'screen_shot'])
                    ->make(true);
            }
            return view('admin.contactus-list');


            //    $data =  $this->adminrepository->getContact();

            //    return view('admin.contactus-list',compact('data'));

        } catch (\Exception $e) {
            log::error('Error in DashboardController/contactusList :' . $e->getMessage() . 'in line' . $e->getLine());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
    public function getContact(Request $request)
    {
        try {
            return   $this->contentRepository->getSingleContact(['id' => $request->id]);
        } catch (\Exception $e) {
            log::error('Error in DashboardController/getContact :' . $e->getMessage() . 'in line' . $e->getLine());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }


    public function getContent()
    {
        try {
            $contentData  = $this->contentRepository->getByWhere([]);
            return view('admin.content', compact('contentData'));
        } catch (\Exception $e) {
            log::error('Error in DashboardController/getContent :' . $e->getMessage() . 'in line' . $e->getLine());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function storeContent(ContentRequest $request)
    {
        try {
            
            $this->adminServices->updateContent($request);

            return response()->json(['status' => '2', 'message' => __('message.statusTwo', ['parameter' => 'Content'])]);
        } catch (\Exception $e) {
            log::error('Error in ContentController/updateContent :' . $e->getMessage() . 'in line' . $e->getLine());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function addFaq(FaqRequest $request)
    {

        try {
            $data['question'] = $request->question;
            $data['answer'] = $request->answer;
            $success = $this->contentRepository->createfaq($data);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusOne', ['parameter' => 'FAQ'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (\Exception $e) {
            Log::error("DashboardController : addFaq()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function faqDelete(Request $request, $id)
    {
        try {

            $success = $this->contentRepository->deletefaq(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusThree', ['parameter' => 'FAQ'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (\Exception $e) {
            Log::error("DashboardController : faqDelete()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function faqshow($id)
    {
        try {

            $success = $this->contentRepository->getOnefaq(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'data' => $success, 'message' => __('message.statusThree', ['parameter' => 'FAQ'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (\Exception $e) {
            Log::error("LocationController : show()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function updateFaq(FaqRequest $request, $id)
    {

        try {
            $data['question'] = $request->question;
            $data['answer'] = $request->answer;

            $success = $this->contentRepository->updatefaq(['id' => $id], $data);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusTwo', ['parameter' => 'FAQ'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (\Exception $e) {
            Log::error("LocationController : update()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    
}
