<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Repository\Eloquent\FoodTypeRepository;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Exception;
use Illuminate\Support\Facades\Redis;
use App\Http\Requests\Admin\FoodTypeRequest;
use App\Traits\UploadImageTrait;
use Illuminate\Support\Facades\File;


class FoodTypeController extends Controller
{
    use UploadImageTrait;
    protected $FoodTypeRepository;

    public function __construct(FoodTypeRepository $FoodTypeRepository)
    {
        $this->FoodTypeRepository = $FoodTypeRepository;
        // $this->appsettingrepository = $appsettingrepository;
    }

    public function get()
    {
        $data = $this->FoodTypeRepository->getAll();
        // dd($data);
        return view('admin.food-type', compact('data'));
    }

    public function add(FoodTypeRequest $request)
    {
        try {
            $data['name_en'] = $request->name_en;
            $data['name_ar'] = $request->name_ar;
            $success = $this->FoodTypeRepository->create($data);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusOne', ['parameter' => 'Type'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("TypeController : add()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function update(FoodTypeRequest $request, $id)
    {
        // dd($request);
        try {
            $data = $this->FoodTypeRepository->getOne(['id' => $id]);

            $value['name_en'] = $request->name_en;
            $value['name_ar'] = $request->name_ar;

            $success = $this->FoodTypeRepository->update(['id' => $id], $value);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusTwo', ['parameter' => 'Type'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("TypeController : update()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function delete(Request $request, $id)
    {
        try {

            $success = $this->FoodTypeRepository->delete(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusThree', ['parameter' => 'Type'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("TypeController : TypeDelete()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function show($id)
    {
        try {

            $success = $this->FoodTypeRepository->getOne(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'data' => $success, 'message' => __('message.statusThree', ['parameter' => 'Type'])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("TypeController : show()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }
}
