<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Repository\Eloquent\FoodTypeRepository;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Exception;
use App\Http\Requests\Api\EditOrderRequest;
use App\Http\Requests\Api\PlaceOrderRequest;
use Illuminate\Support\Facades\Auth;
use App\Http\Requests\Api\BankRequest;
use App\Services\Users\OrderServices;
use App\Repository\Eloquent\CategoryRepository;
use App\Repository\Eloquent\TypeRepository;
use App\Repository\Eloquent\OrderRepository;
use App\Repository\Eloquent\ReportRepository;
use Yajra\DataTables\Facades\DataTables;
use App\Models\Review;

class OrderController extends Controller
{
    protected $orderService;
    private $dataObject;
    protected $orderRepository;
    protected $ReportRepository;

    public function __construct(ReportRepository $ReportRepository,OrderServices $orderService, OrderRepository $orderRepository)
    {
        $this->dataObject = new \stdClass();
        $this->orderService = $orderService;
        $this->orderRepository = $orderRepository;
        $this->ReportRepository = $ReportRepository;
    }

    public function index(Request $request)
    {
        try {
            // dd($request);

            $data = $this->orderRepository->getAll();
            if ($data) {
                if (!$data->isEmpty()) {
                    foreach ($data as $order) {
                        if ($order->orderItems) {
                            foreach ($order->orderItems as $item) {
                                if ($item->menu) {

                                    $uploadImages = $item->menu->upload_images;
                                    if (is_string($uploadImages)) {
                                        $uploadImagesArray = json_decode($uploadImages, true);

                                        if (json_last_error() !== JSON_ERROR_NONE) {
                                        }
                                    } elseif (is_array($uploadImages)) {
                                        $uploadImagesArray = $uploadImages;
                                    } else {
                                        $uploadImagesArray = [];
                                    }

                                    $item->menu->upload_images = $uploadImagesArray;
                                }
                            }
                        }
                    }
                }
                // dd($data);
                return view('admin.order-list', compact('data'));
            }
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function show(Request $request, $id)
    {
        try {
            // dd($id);
            $order = $this->orderRepository->getOne(['id' => $id]);
            // dd($order);
            $reviews = Review::where('order_id', $order->id)->with('chef')->get(); 
            $averageRating = $reviews->count() > 0 ? $reviews->avg('rating') : null;
            if (!$order) {
                return redirect()->route('admin.dashboard')->withErrors(['error' => __('order not found')]);
            }
            return view('admin.order-detail', compact('order','reviews','averageRating'));
        } catch (Exception $e) {
            Log::error("UserAdminController : show() " . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function reportList(Request $request)
    {
        try {
            // dd($request);

            if ($request->ajax()) {

                $data = $this->ReportRepository->getAll();
                return Datatables::of($data)
                    ->editColumn('chefName', function ($row) {
                        $chefName = isset($row->chef->name) ? $row->chef->name : '';
                        return $chefName;
                    })
                    ->editColumn('UserName', function ($row) {
                        $UserName = isset($row->user->name) ? $row->user->name : '';
                        return $UserName;
                    })
                    ->editColumn('message', function ($row) {
                        $message = isset($row->message) ?  substr($row->message, 0, 100) . '.....' : '';
                        return $message;
                    })
                    ->addColumn('sn', function ($timeTable) {
                        static $i = 0;
                        $i++;
                        return $i;
                    })
                    ->addColumn('action', function ($row) {
                        $viewBtn = ' <button href="javascript:void(0)" class="btn btn-primary btn-sm"  onclick="return getReportData(' . $row->id . ')">
                                        View
                                    </button>';
                        return  $viewBtn;
                    })
                    ->rawColumns(['action', 'UserName','chefName', 'message'])
                    ->make(true);
            }

                return view('admin.report-list');
            
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function getreport(Request $request)
    {
        try {
            return $this->ReportRepository->getOne(['id' => $request->id]);
        } catch (\Exception $e) {
            log::error('Error in OrderController/getreport :' . $e->getMessage() . 'in line' . $e->getLine());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
}
