<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Hash;
use App\Models\Admin;
use Illuminate\Support\Facades\Mail;
use App\Mail\TemporaryPasswordMail;
use Illuminate\Support\Facades\Log;
use Exception;

class PasswordResetController extends Controller
{
    //
    public function sendResetLinkEmail(Request $request)
    {
        try {

            $request->validate([
                'email' => 'required|email',
            ]);

            $user = Admin::where('email', $request->email)->first();
            
            if (!$user) {
                return back()->withErrors(['email' =>__('message.email_not_found')]);
            }

            $tempPassword = Str::random(10); // Generate a temporary password
            $user->password = Hash::make($tempPassword); // Update user password
            $user->save();

            

            // Send temporary password email
            Mail::to($user->email)->send(new TemporaryPasswordMail($tempPassword));

            return back()->with('status',  __('message.checkEmail'));

        } catch (Exception $e) {
            Log::error("PasswordResetController : logout()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.login')->withErrors(['error' => __('message.something_went_wrong')]);

        }
    }
}
