<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Repository\Eloquent\PlanRepository;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Exception;
use Illuminate\Support\Facades\Redis;
use App\Http\Requests\Admin\PlanRequest;
use App\Services\Admin\PlanServices;
use App\Traits\UploadImageTrait;
use Illuminate\Support\Facades\File;

class PlanController extends Controller
{
    use UploadImageTrait;
    protected $PlanRepository;
    protected $PlanServices;

    public function __construct(PlanRepository $PlanRepository,PlanServices $PlanServices)
    {
        $this->PlanRepository = $PlanRepository;
        $this->PlanServices = $PlanServices;
    }

    public function get()
    {
        $data = $this->PlanRepository->getAll();
        return view('admin.plan', compact('data'));
    }


    public function add(PlanRequest $request)
    {
        try {
            
            return $this->PlanServices->create($request);
            
        } catch (Exception $e) {
            Log::error("PlanController : add()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function show($id)
    {
        try {

            $success = $this->PlanRepository->getOne(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'data' => $success, 'message' => __('message.statusFour', ['parameter' => __('message.plan')])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("PlanController : show()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function update(PlanRequest $request)
    {
        // dd($request);
        try {
            return $this->PlanServices->update($request);
        } catch (Exception $e) {
            Log::error("CategoryController : update()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function delete(Request $request, $id)
    {
        try {

            $success = $this->PlanRepository->delete(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.statusThree', ['parameter' =>  __('message.plan')])]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("PlanController : TypeDelete()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function getSubscriptions()
    {
        try {

            $data = $this->PlanRepository->getAllPurchase();
            // dd($data);
            if ($data) {
                return view('admin.subscriptions-list', compact('data'));
            }
        } catch (Exception $e) {
            Log::error("PlanController : getSubscriptions()" . $e->getLine() . " " . $e->getMessage());
            throw $e;
        }
    }


}