<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Traits\UploadImageTrait;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\File;
use App\Http\Requests\Admin\ProfileUpdateRequest;
use App\Http\Requests\Admin\ProfileUpdatePasswordRequest;
use App\Services\Admin\AdminServices;
// use App\Repository\Eloquent\AppSettingRepository;
use Exception;

class ProfileController extends Controller
{

    use UploadImageTrait;
    protected $adminService;
    // protected $userRepository,$appsettingrepository;


    public function __construct(AdminServices $adminService)
    {
        $this->adminService = $adminService;
        // $this->appsettingrepository = $appsettingrepository;
    }

    public function edit(Request $request)
    {
        try {
            $user = Auth::guard('admin')->user();
         
            return view('admin.profile.profile-edit', compact('user'));
        } catch (Exception $e) {
            Log::error("ProfileController : edit()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function update(ProfileUpdateRequest $request)
    {
        
        try {
            $user = Auth::guard('admin')->user();

            $user->name = $request->name;
            $user->email = $request->email;

            if ($request->profile_image) {
                $imagePath = $this->uploadImage($request->profile_image, 'profileImages');

                // Delete old image if exists
                if ($imagePath) {
                    // Delete old image if exists
                    if ($user->profile_image) {
                        $adminPath = storage_path('app/public/');
                        $oldImagePath = $adminPath . ($user->profile_image);
                        if (File::exists($oldImagePath)) {
                            File::delete($oldImagePath);
                        }
                    }
                    $user->profile_image = $imagePath;
                }
            }

            // dd($user);

            $user->save();


            return response()->json(['success' => true, 'message' => __('message.profileUpdate')]); // Return a JSON response for AJAX

        } catch (Exception $e) {
            Log::error("ProfileController : update()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function viewPassword(Request $request)
    {
        try {
            return view('admin.profile.changepassword', [
                'user' => Auth::guard('admin')->user(),
            ]);
        } catch (Exception $e) {
            Log::error("ProfileController : viewPassword()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function updatePassword(ProfileUpdatePasswordRequest $request)
    {
        try {
            $result = $this->adminService->updatePassword($request->input('old_password'), $request->input('new_password'));
           
            if (!$result) {
                return response()->json(['status' => false, "message" => __('message.old_pass_not_match')]);
            }

            // session()->flash('status', 'Password updated successfully!');
            return response()->json(['status' => true, "message" => __('message.password_changed')]);
        } catch (Exception $e) {
            Log::error("ProfileController : updatePassword()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);

        }

    }
    

}
