<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Http\Requests\Admin\DrawSettingRequest;
use Illuminate\Support\Facades\Log;
use App\Repository\Eloquent\UserRepository;
use App\Repository\Eloquent\MenuRepository;
use Illuminate\Support\Facades\Mail;
use App\Mail\AcceptbyAdminMail;
use App\Mail\RejectbyAdminMail;
use App\Services\Users\UserServices;
use Yajra\DataTables\Facades\DataTables;
use App\Models\Game;
use App\Repository\Eloquent\ReviewRepository;
use App\Repository\Eloquent\PlanRepository;
use Exception;


class UserAdminController extends Controller
{
    protected $userRepository;
    protected $UserServices;
    protected $PlanRepository;
    protected $MenuRepository,$reviewRepository;

    public function __construct(UserRepository $userRepository, UserServices $UserServices,PlanRepository $PlanRepository,MenuRepository $MenuRepository,ReviewRepository $reviewRepository)
    {
        $this->userRepository = $userRepository;
        $this->UserServices = $UserServices;
        $this->PlanRepository = $PlanRepository;
        $this->reviewRepository = $reviewRepository;
        $this->MenuRepository = $MenuRepository;
    }

    public function index()
    {
        try {
            $conditions = [
                'user_status' => 0,
                'email_verified_at' => ['!=', null],
                'phone_verified_at' => ['!=', null],
                'user_type' => 2
            ];
            $users = $this->userRepository->getByWhere($conditions);

            return view('admin.incoming-chef', compact('users'));
        } catch (Exception $e) {
            Log::error("UserAdminController : index() " . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function activeChef()
    {
        try {
            $conditions = ['user_status' => ['!=', 0], 'user_type' => 2];
            $activeUsers = $this->userRepository->getByWhere($conditions);
       
            return view('admin.active-chef', compact('activeUsers'));
        } catch (Exception $e) {
            Log::error("UserAdminController : activeUser() " . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function activeUser()
    {
        try {
            $conditions = ['user_status' => ['!=', 0], 'user_type' => 1]; // Condition for active users
            $activeUsers = $this->userRepository->getByWhere($conditions);
           
            return view('admin.active-user', compact('activeUsers'));
        } catch (Exception $e) {
            Log::error("UserAdminController : activeUser() " . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function show(Request $request, $id)
    {
        try {
            // dd($id);
            $user = $this->userRepository->getOne(['id' => $id]);
            $allsubscription = $this->PlanRepository->getAllPurchase(['user_id' => $id]);
            $menu_data = $this->MenuRepository->getAll(['user_id' => $id]);
            // dd($menu_data);
            $condition['chef_id'] = $id;
            $reviews = $this->reviewRepository->getByWhere($condition);
            $ratings = $this->reviewRepository->getAverageRatingAndCount($id);
            $conditions = ['refferal_code' => $user->chef_refferal_code, 'referred_by_id' => $id];
            $Refrred_user = $this->userRepository->getByWhere($conditions);
            // dd($Refrred_user);
            if (!$user) {
                return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.user_not_found')]);
            }
            return view('admin.userdetails', compact('user','allsubscription','menu_data','reviews','ratings','Refrred_user'));
        } catch (Exception $e) {
            Log::error("UserAdminController : show() " . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }


    public function block($id)
    {
        try {
            $value['user_status'] = 2;

            $success = $this->userRepository->update(['id' => $id], $value);
            // dd($success);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.user_blocked')]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("UserAdminController : block() " . $e->getLine() . " " . $e->getMessage());
            return response()->json(['status' => false, 'message' => __('message.something_went_wrong')], 500);
        }
    }

    public function unblock($id)
    {
        try {
            $value['user_status'] = 1;

            $success = $this->userRepository->update(['id' => $id], $value);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.user_unblocked')]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("UserAdminController : unblock() " . $e->getLine() . " " . $e->getMessage());
            return response()->json(['status' => false, 'message' => __('message.something_went_wrong')], 500);
        }
    }

    public function toggleFeatured(Request $request,$id)
    {
        try {
            $value['is_featured'] = $request->is_featured;

            $success = $this->userRepository->update(['id' => $id], $value);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.user_feature')]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("UserAdminController : unblock() " . $e->getLine() . " " . $e->getMessage());
            return response()->json(['status' => false, 'message' => __('message.something_went_wrong')], 500);
        }
    }


    

    public function accept(Request $request, $id)
    {
        // dd($request);
        try {
            $value['user_status'] = 1;

            try {
                $userDetails = $this->userRepository->getOne(['id' => $id]);
                // dd($userDetails);
                Mail::to($userDetails->email)->send(new AcceptbyAdminMail($userDetails));
            } catch (Exception $e) {
                Log::error("UserAdminController : mail() " . $e->getLine() . " " . $e->getMessage());
            }


            $success = $this->userRepository->update(['id' => $id], $value);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.user_accepted')]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("UserAdminController : accept() " . $e->getLine() . " " . $e->getMessage());
            return response()->json(['status' => false, 'message' => __('message.something_went_wrong')], 500);
        }
    }

    public function reject(Request $request, $id)
    {

        try {
            try {
                $userDetails = $this->userRepository->getOne(['id' => $id]);
                $userDetails['message'] = $request->reason;
                Mail::to($userDetails->email)->send(new RejectbyAdminMail($userDetails));
            } catch (Exception $e) {
                Log::error("UserAdminController : mail() " . $e->getLine() . " " . $e->getMessage());
            }
            $success = $this->userRepository->delete(['id' => $id]);
            if ($success) {
                return response()->json(['status' => true, 'message' => __('message.user_rejected')]);
            } else {
                return response()->json(['status' => false], 500);
            }
        } catch (Exception $e) {
            Log::error("UserAdminController : reject() " . $e->getLine() . " " . $e->getMessage());
            return response()->json(['status' => false, 'message' => __('message.something_went_wrong')], 500);
        }
    }


    public function getMenu(Request $request)
    {
        try {
            return $this->MenuRepository->getOne(['id' => $request->id]);
        } catch (\Exception $e) {
            log::error('Error in UserAdminController/getMenu :' . $e->getMessage() . 'in line' . $e->getLine());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
    


}