<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Repository\Eloquent\FavouriteRepository;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use Exception;
use App\Http\Requests\Api\FavoriteRequest;
use App\Http\Requests\Api\ReviewRequest;
use App\Models\Favorite;
use App\Traits\UploadImageTrait;
use Illuminate\Support\Facades\Auth;
use App\Services\Users\FavouriteServices;

class FavoriteController extends Controller
{
    use UploadImageTrait;

    protected $FavouriteRepository;
    protected $FavouriteServices;
    private $dataObject;

    public function __construct(FavouriteRepository $FavouriteRepository, FavouriteServices $FavouriteServices)
    {
        $this->FavouriteRepository = $FavouriteRepository;
        $this->dataObject = new \stdClass();
        $this->FavouriteServices = $FavouriteServices;
    }

    public function addToFavorite(FavoriteRequest $request)
    {
        try {
            return $this->FavouriteServices->addToFavorite($request);
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function myFavoriteList(Request $request)
    {
        try {
            return $this->FavouriteServices->myFavoriteList($request);
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function removeFromFavorite(FavoriteRequest $request)
    {
        try {
            return $this->FavouriteServices->removeFromFavorite($request);
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

}
