<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Services\Users\UserServices;
use Illuminate\Http\Request;
use App\Http\Requests\Api\MenuRequest;
use App\Repository\Eloquent\UserRepository;
use App\Repository\Eloquent\MenuRepository;
use App\Http\Requests\Api\LoginRequest;
use App\Http\Requests\Api\UniqueRequest;
use App\Http\Requests\Api\ForgetPasswordRequest;
use App\Http\Requests\Api\PurchaseRequest;
use App\Http\Requests\Api\UpdateMenuRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use App\Http\Requests\Api\BankRequest;
use App\Services\Users\MenuServices;
use App\Repository\Eloquent\CategoryRepository;
use App\Repository\Eloquent\TypeRepository;
use App\Repository\Eloquent\FoodTypeRepository;
use Exception;

class MenuController extends Controller
{
    protected $MenuRepository;
    protected $CategoryRepository;
    protected $TypeRepository;
    protected $MenuServices;
    protected $FoodTypeRepository;
    private $dataObject;

    public function __construct(MenuRepository $MenuRepository, MenuServices $MenuServices, CategoryRepository $CategoryRepository, TypeRepository $TypeRepository, FoodTypeRepository $FoodTypeRepository)
    {
        $this->dataObject = new \stdClass();
        $this->MenuRepository = $MenuRepository;
        $this->MenuServices = $MenuServices;
        $this->CategoryRepository = $CategoryRepository;
        $this->TypeRepository = $TypeRepository;
        $this->FoodTypeRepository = $FoodTypeRepository;
    }

    public function menuAdd(MenuRequest $request)
    {
        try {
            return $this->MenuServices->menuAdd($request);
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function menuEdit(UpdateMenuRequest $request)
    {
        try {
            return $this->MenuServices->menuEdit($request);
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function menuList(Request $request)
    {
        try {
            $limit = $request->limit ?? 10;
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }

            $condition = ['user_id' => $user->id];

            if ($request->has('keyword')) {
                $keyword = $request->input('keyword');
                $data = $this->MenuRepository->getAll($condition, $limit, $keyword);
            } else {
                $data = $this->MenuRepository->getAll($condition, $limit);
            }
            if ($data) {
                if (!$data->isEmpty()) {
                    foreach ($data as $value) {
                        $value->upload_images = json_decode($value->upload_images);
                    }
                }
            
                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            }
        } catch (\Exception $e) {
            Log::error("Error in MenuController.menuList(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
    public function menuAll(Request $request)
    {
        try {


            return $this->MenuServices->menuList($request);
        } catch (\Exception $e) {
            Log::error("Error in MenuController.menuList(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function menuDetail(Request $request)
    {

        try {
            $data =  $this->MenuRepository->getOne(['id' => $request->id]);

            if ($data) {

                $data->upload_images = json_decode($data->upload_images);


                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.some_thing_went_wrong'), 'data' => $this->dataObject, 'status' => 0]);
            }
        } catch (\Exception $e) {
            Log::error("Error in MenuController.menuDetail(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }



    public function deleteMenu(Request $request)
    {
        try {
            $success = $this->MenuRepository->delete(['id' => $request->id]);
            if ($success) {
                return response()->json(['message' =>  __('message.statusThree', ['parameter' => __('message.menu')]), 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (\Exception $e) {
            Log::error("Error in MenuController.deleteMenu(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function categoryList()
    {

        try {
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }

            $data = $this->CategoryRepository->getAll();
            if ($data) {
                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            }
        } catch (\Exception $e) {
            Log::error("Error in MenuController.menuList(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function typeList()
    {

        try {
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }

            $data = $this->TypeRepository->getAll();
            if ($data) {
                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            }
        } catch (\Exception $e) {
            Log::error("Error in MenuController.menuList(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
    public function foodtypeList()
    {

        try {
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }

            $data = $this->FoodTypeRepository->getAll();
            if ($data) {
                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            }
        } catch (\Exception $e) {
            Log::error("Error in MenuController.menuList(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
}
