<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Services\Users\UserServices;
use Illuminate\Http\Request;
use App\Http\Requests\Api\MenuRequest;
use App\Repository\Eloquent\UserRepository;
use App\Repository\Eloquent\MenuRepository;
use App\Http\Requests\Api\LoginRequest;
use App\Http\Requests\Api\UniqueRequest;
use App\Http\Requests\Api\ReviewRequest;
use App\Http\Requests\Api\EditOrderRequest;
use App\Http\Requests\Api\PlaceOrderRequest;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use App\Http\Requests\Api\BankRequest;
use App\Services\Users\OrderServices;
use App\Repository\Eloquent\ReviewRepository;
use App\Repository\Eloquent\TypeRepository;
use App\Repository\Eloquent\OrderRepository;
use Exception;

class OrderController extends Controller
{
    protected $orderService;
    private $dataObject;
    protected $orderRepository, $reviewRepository;

    public function __construct(OrderServices $orderService, OrderRepository $orderRepository, ReviewRepository $reviewRepository)
    {
        $this->dataObject = new \stdClass();
        $this->orderService = $orderService;
        $this->reviewRepository = $reviewRepository;
        $this->orderRepository = $orderRepository;
    }

    public function placeOrder(PlaceOrderRequest $request)
    {
        try {
            // dd($request);
            return $this->orderService->placeOrder($request);
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }
    public function getOrder(Request $request)
    {
        try {
            return $this->orderService->getOrder($request);
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function orderDetail(Request $request)
    {
        try {
            $data =  $this->orderRepository->getOne(['id' => $request->id]);

            if ($data) {


                if ($data->orderItems) {

                    foreach ($data->orderItems as $item) {

                        if ($item->menu) {


                            $uploadImages = $item->menu->upload_images;
                            if (is_string($uploadImages)) {
                                $uploadImagesArray = json_decode($uploadImages, true);

                                if (json_last_error() !== JSON_ERROR_NONE) {
                                }
                            } elseif (is_array($uploadImages)) {
                                $uploadImagesArray = $uploadImages;
                            } else {
                                $uploadImagesArray = [];
                            }

                            $item->menu->upload_images = $uploadImagesArray;
                        }
                    }
                }


                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.some_thing_went_wrong'), 'data' => $this->dataObject, 'status' => 0]);
            }
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }


    public function editOrder(EditOrderRequest $request)
    {
        try {
            // dd($request);
            return $this->orderService->editOrder($request);
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function addReview(ReviewRequest $request)
    {
        try {
            // dd($request);
            return $this->orderService->addReview($request);
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function reviewList(Request $request)
    {

        try {
            $user = auth()->user();
            $perPage = $request->input('limit', 10);
            // $condition = ['user_id' => $user->id];
            if ($request->chef_id) {
                $condition['chef_id'] = $request->chef_id;
            }
            $data = $this->reviewRepository->getByWhere($condition, ['id' => 'desc'], $perPage);

            if (isset($data) && !empty($data)) {
                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function transactionHistory(Request $request)
    {
        try {
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }
            $limit = $request->limit ?? 10;

            $data = $this->orderRepository->getByWhere(['user_id' => $user->id],$limit);

            if (isset($data) && !empty($data)) {
                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }
}
