<?php

namespace App\Http\Requests\Admin;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class PlanRequest extends FormRequest
{
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, \Illuminate\Contracts\Validation\Rule|array|string>
     */
    public function rules(): array
    {
        $rules = [
            'plan_title' => ['required', 'string', 'max:255'],
            'description' => ['required', 'string'],
            'cost' => ['required', 'numeric', 'min:0'],
            'number_of_days' => ['required', 'integer'],
            'discount_percentage' => ['nullable', 'numeric', 'between:0,100'] // Optional field
           
        ];

        if ($this->isMethod('post')) {
            $rules['plan_title'][] = 'unique:work_plans'; 
        } elseif ($this->isMethod('put') || $this->isMethod('patch')) {
            $planId = $this->route('id'); // Adjust this based on how you pass the ID

            $rules['plan_title'][] = Rule::unique('work_plans')->ignore($planId); // Ensure title is unique except for the current record
        }

        return $rules;
    }
}
