<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Request;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Http\Exceptions\HttpResponseException;
use Illuminate\Validation\Rule;

class MenuRequest extends FormRequest
{

    private $dataObject;

    public function __construct()
    {
        // Initialize $dataObject as a new stdClass object
        $this->dataObject = new \stdClass();
    }

    public function rules()
    {

        return [
            'item_name' => 'required|string|max:255',
            'upload_images' => 'required', 
            'price' => 'required|numeric|min:0',
            'category_id' => 'required|array',
            'category_id.*' => 'exists:categories,id',
            'minimum_deposit' => 'nullable|numeric|min:0',
            'type_id' => 'required|exists:types,id',
            'foodtype_id' => 'required|exists:food_types,id',
            'preparation_notice' => 'nullable|string',
            'preparation_time' => 'required|numeric',
            'detail' => 'required|string',
        ];
        
    }
    public function messages()
    {
        return [
            'item_name.required' => __('message.validation.item_name_required'),
        'item_name.string' => __('message.validation.item_name_string'),
        'item_name.max' => __('message.validation.item_name_max'),

        'upload_images.required' => __('message.validation.upload_images_required'),

        'price.required' => __('message.validation.price_required'),
        'price.numeric' => __('message.validation.price_numeric'),
        'price.min' => __('message.validation.price_min'),

        'category_id.required' => __('message.validation.category_id_required'),
        'category_id.array' => __('message.validation.category_id_array'),
        'category_id.*.exists' => __('message.validation.category_id_exists'),

        'minimum_deposit.numeric' => __('message.validation.minimum_deposit_numeric'),
        'minimum_deposit.min' => __('message.validation.minimum_deposit_min'),

        'type_id.required' => __('message.validation.type_id_required'),
        'type_id.exists' => __('message.validation.type_id_exists'),

        'foodtype_id.required' => __('message.validation.foodtype_id_required'),
        'foodtype_id.exists' => __('message.validation.foodtype_id_exists'),

        'preparation_notice.string' => __('message.validation.preparation_notice_string'),

        'preparation_time.required' => __('message.validation.preparation_time_required'),
        'preparation_time.numeric' => __('message.validation.preparation_time_numeric'),

        'detail.required' => __('message.validation.detail_required'),
        'detail.string' => __('message.validation.detail_string'),
        ];
    }

    protected function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(response()->json([
            'message' => 'Validation failed',
            'data' => $this->dataObject,
            'status' => 0,
            'errors' => $validator->errors(),
        ], 400));
    }
}
