<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;
use Illuminate\Contracts\Validation\Validator;

class ReviewRequest extends FormRequest
{
    public function authorize()
    {
        return true; // Adjust based on your authorization logic
    }

    public function rules()
    {
        return [
            'order_id' => 'required|exists:order_masters,id|unique:reviews,order_id,NULL,id,chef_id,' . $this->chef_id,
            'chef_id' => 'required|exists:users,id',
            'rating' => 'required|integer|between:1,5', // Adjust according to your rating system
            'message' => 'nullable|string|max:255', // Adjust based on your needs
        ];
    }

    public function messages()
    {
        return [
            'order_id.exists' => __('message.validation.order_id_exists'),
            'order_id.unique' => __('message.validation.order_id_unique'),
        ];
    }

    protected function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(response()->json([
            'errors' => $validator->errors(),
        ], 422));
    }
}
