<?php

namespace App\Http\Requests\Api;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Request;
use Illuminate\Contracts\Validation\Validator;
use Illuminate\Http\Exceptions\HttpResponseException;
use Illuminate\Validation\Rule;
use App\Models\User;

class SignupRequest extends FormRequest
{

    private $dataObject;

    public function __construct()
    {
        // Initialize $dataObject as a new stdClass object
        $this->dataObject = new \stdClass();
    }

    public function rules(Request $request)
    {
        $rules = [
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'password' => 'required|min:6',
            'phone_no' => [
                'required',
                Rule::unique('users')->where(function ($query) {
                    return $query->where('phone_code', $this->phone_code);
                }),
            ],
            'user_type' => 'required',
            'phone_code' => 'required',
        ];

        // Additional validation rules for chefs (user_type == 2)
        if ($request->user_type == 2) {
            $rules['lat'] = 'required|numeric';
            $rules['lng'] = 'required|numeric';
            $rules['address'] = 'required';
        }

        // Validation for users (user_type == 1)
        if ($request->user_type == 1) {
            $rules['refferal_code'] = [
                'nullable',  // Make referral code optional
                'exists:users,chef_refferal_code',  // Checks if the referral code exists in the users table (only if provided)
                function ($attribute, $value, $fail) use ($request) {
                    // Only run this check if the referral code is provided
                    if ($value) {
                        $user = User::where('chef_refferal_code', $value)->first();
                        // if (!$user) {
                        //     return $fail('The provided referral code is invalid.');
                        // }
                        // You can also add other validation logic based on the referred user's status, etc.
                    }
                },
            ];
        }

        return $rules;
    }

    public function messages()
    {
        return [
            'name.required' => __('message.validation.name_required'),
            'email.required' => __('message.validation.email_required'),
            'email.email' => __('message.validation.email_invalid'),
            'email.unique' => __('message.validation.email_unique'),
            'password.required' => __('message.validation.password_required'),
            'password.min' => __('message.validation.password_min'),
            'phone_no.required' => __('message.validation.phone_no_required'),
            'phone_no.unique' => __('message.validation.phone_no_unique'),
            'user_type.required' => __('message.validation.user_type_required'),
            'phone_code.required' => __('message.validation.phone_code_required'),
            'lat.required' => __('message.validation.lat_required'),
            'lat.numeric' => __('message.validation.lat_numeric'),
            'lng.required' => __('message.validation.lng_required'),
            'lng.numeric' => __('message.validation.lng_numeric'),
            'address.required' => __('message.validation.address_required'),
            'refferal_code.exists' => __('message.validation.refferal_code_exists'),
            'refferal_code.required' => __('message.validation.refferal_code_required'),
        ];
    }
    

    protected function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(response()->json([
            'message' => 'Validation failed',
            'data' => $this->dataObject,
            'status' => 0,
            'errors' => $validator->errors(),
        ], 400));
    }
}
