<?php

namespace App\Repository\Eloquent;

use App\Models\ContentManagement;
use App\Models\ContactUs;
use Illuminate\Contracts\Cache\Repository as Cache;
use Illuminate\Support\Facades\Log;


class ContentRepository extends BaseRepository
{

    protected $model;
    protected $cache;
    protected $contactmodel;
    public function __construct(ContactUs $contactmodel, ContentManagement $model, Cache $cache)
    {
        $this->model = $model;
        $this->contactmodel = $contactmodel;
        parent::__construct($model, $cache);
    }
    //its a create function used insert data 

    public function getOne($byWhere)
    {
        try {
            return $this->model->where($byWhere)->first();
        } catch (\Exception $e) {
            Log::error("Error in ContentRepository.getOne(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
    public function getContact()
    {
        try {
            return $this->contactmodel->orderBy('id', 'desc')->get();
        } catch (\Exception $e) {
            Log::error("Error in ContentRepository.getContact(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function getSingleContact($byWhere)
    {
        try {
            return $this->contactmodel->where($byWhere)->first();
        } catch (\Exception $e) {
            Log::error("Error in ContentRepository.getSingleContact(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function createContact($allData)

    {
        try {

            return $this->contactmodel->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in ContentRepository.createContact(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }

    public function getByWhere($bywhere)
    {
        try {
            return $this->model->where($bywhere)->orderBy('id', 'asc')->get();
        } catch (\Exception $e) {
            Log::error("Error in ContentRepository.getByWhere(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function update($byWhere, $Data)
    {
        try {

            return $this->model->where($byWhere)->update($Data);
        } catch (\Exception $e) {
            Log::error("Error in ContentRepository.update(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }


    public function createfaq($allData)

    {
        try {

            return $this->faqmodel->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in ContentRepository.createfaq(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }

    public function updatefaq($byWhere, $Data)
    {
        try {

            return $this->faqmodel->where($byWhere)->update($Data);
        } catch (\Exception $e) {
            Log::error("Error in ContentRepository.updatefaq(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function deletefaq($byWhere)

    {

        try {

            return $this->faqmodel->where($byWhere)->delete();
        } catch (\Exception $e) {

            Log::error("Error in ContentRepository.deletefaq(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function getAllfaq()
    {
        try {

            return $this->faqmodel->orderBy('id', 'desc')->get();
        } catch (\Exception $e) {

            Log::error("Error in userRepository.userList(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function getOnefaq($byWhere)
    {

        try {
            return $this->faqmodel->where($byWhere)->first();
        } catch (\Exception $e) {
            Log::error("Error in ContentRepository.getOnefaq(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }
}
