<?php

namespace App\Repository\Eloquent;

use App\Models\Favorite;
use Illuminate\Contracts\Cache\Repository as Cache;
use Illuminate\Support\Facades\Log;
use Carbon\Carbon;
use Illuminate\Support\Facades\DB;


class FavouriteRepository extends BaseRepository
{

    protected $model;
    protected $cache;
    public function __construct(Favorite $model, Cache $cache)
    {
        $this->model = $model;
        parent::__construct($model, $cache);
    }

    public function create($allData)

    {
        try {

            return $this->model->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in FavouriteRepository.create(): " . $e->getMessage());

            throw $e;
        }
    }
    public function getOne($byWhere)
    {

        try {
            return $this->model->where($byWhere)->with('menu')->first();
        } catch (\Exception $e) {
            Log::error("Error in FavouriteRepository.getOne(): " . $e->getMessage());
            throw $e;
        }
    }

    public function getAll($byWhere,$orderBy = null,)
    {

        try {
            $query = $this->model->where($byWhere)->with('menu','user');
            if ($orderBy === null) {
                $query->orderBy('created_at', 'desc');
            } else {
                foreach ($orderBy as $column => $direction) {
                    $query->orderBy($column, $direction);
                }
            }
            return $query->get();
        } catch (\Exception $e) {
            Log::error("Error in FavouriteRepository.getAll(): " . $e->getMessage());
            throw $e;
        }
    }

    public function getByWhere($byWhere, $orderBy = ['created_at' => 'desc'], $perpage = null, $keyword = null)
    {
        try {
            $query = $this->model->with(['menu' => function ($q) {
                $q->select('menus.*', DB::raw('1 AS is_favorite')); // Add is_favorite to the menu items
            }, 'user'])
            ->where(function ($query) use ($byWhere) {
                foreach ($byWhere as $column => $condition) {
                    if (is_array($condition)) {
                        if ($condition[0] === "IN") {
                            unset($condition[0]);
                            $query->whereIn($column, $condition);
                        } else {
                            $query->where($column, $condition[0], $condition[1]);
                        }
                    } else {
                        $query->where($column, $condition);
                    }
                }
            });
            if ($keyword) {
                $query->whereHas('menu', function ($q) use ($keyword) {
                    $q->where('item_name', 'like', '%' . $keyword . '%');
                });
            }
            // Construct the order by string only if there are order conditions
            if (!empty($orderBy)) {
                $orderByString = '';
                foreach ($orderBy as $column => $direction) {
                    $orderByString .= "$column $direction, ";
                }
                $orderByString = rtrim($orderByString, ', ');
    
                $query->orderByRaw($orderByString);
            }
          
    
            // Paginate or get the results based on $perpage
            return $perpage ? $query->paginate($perpage) : $query->get();
        } catch (\Exception $e) {
            Log::error("Error in FavouriteRepository.getByWhere(): " . $e->getMessage());
            throw $e;
        }
    }
    

    public function delete($byWhere)

    {

        try {

            return $this->model->where($byWhere)->delete();
        } catch (\Exception $e) {

            Log::error("Error in FavouriteRepository.delete(): " . $e->getMessage());

            throw $e;
        }
    }

    
}
