<?php



namespace App\Repository\Eloquent;



use App\Models\Menu;
use App\Models\Category;
use Illuminate\Contracts\Cache\Repository as Cache;

use Illuminate\Support\Facades\Log;

// use App\Models\NotificationModel;

use DB;



class MenuRepository extends BaseRepository

{
    protected $model;

    protected $cache;
    public function __construct(

        Menu $model,

        Cache $cache,


    ) {

        $this->model = $model;
        parent::__construct($model, $cache);
    }

    public function create($allData)

    {
        // dd($allData);


        try {

            return $this->model->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in MenuRepository.create(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }

    public function update($byWhere, $update)

    {

        try {

            return $this->model->where($byWhere)->update($update);
        } catch (\Exception $e) {

            Log::error("Error in MenuRepository.update(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }



    public function getOne($byWhere)

    {

        try {

            $data = $this->model->select('*')->where($byWhere)->first();

            if ($data) {
                $categoryIds = json_decode($data->category_id, true);
                
                if (!empty($categoryIds)) {
                    $categories = Category::whereIn('id', $categoryIds)->get();
                    $data->category_names = $categories;
                } else {
                    $data->category_names = []; // or null, if you prefer
                }
            }
            return $data;
        } catch (\Exception $e) {

            Log::error("Error in MenuRepository.getOne(): " . $e->getMessage());

            throw $e;
        }
    }





    public function getAll($byWhere = null, $perPage = null, $keyword = null)
    {
        try {
            // Start the query
            $query = $this->model
                ->with('type', 'user', 'foodtype', 'user.chefDetail','favorites')
                ->orderBy('menus.id', 'desc');
    
            // Apply the where condition if provided
            if ($byWhere) {
                $query->where($byWhere);
            }
    
            // Handle keyword search
            if ($keyword) {
                $query->where(function ($q) use ($keyword) {
                    $q->where('menus.item_name', 'like', '%' . $keyword . '%');
                    // $q->where('menus.item_name', 'like', "%$keyword%"); // Adjust 'name' to the appropriate field
                      // Include any other fields you want to search
                });
            }
    
            // Fetch the data, using pagination if perPage is specified
            $data = $perPage ? $query->paginate($perPage) : $query->get();
    
            // Add category names to each menu item
            foreach ($data as $item) {
                $categoryIds = json_decode($item->category_id, true);
                if (!empty($categoryIds)) {
                    // Fetch category names only if category IDs are present
                    $categories = Category::whereIn('id', $categoryIds)->get();
                    $item->category_names = $categories;
                } else {
                    $item->category_names = []; // Ensure it's an empty array if no categories
                }
            }
    
            return $data;
        } catch (\Exception $e) {
            Log::error("Error in MenuRepository.getAll(): " . $e->getMessage());
            throw $e; // Re-throw the exception to be handled by the calling function
        }
    }
    



    public function delete($byWhere)

    {

        try {

            return $this->model->where($byWhere)->delete();

        } catch (\Exception $e) {

            Log::error("Error in MenuRepository.delete(): " . $e->getMessage());

            throw $e;
        }
    }





    public function getByWhere($byWhere, $orderBy = ['id' => 'desc'])

    {

        try {

            $query = $this->model->where(function ($query) use ($byWhere) {



                foreach ($byWhere as $column => $condition) {

                    if (is_array($condition)) {



                        if ($condition[0] === "IN") {

                            unset($condition[0]);

                            $query->whereIn($column, $condition);
                        } else {

                            $query->where($column, $condition[0], $condition[1]);
                        }
                    } else {

                        $query->where($column, $condition);
                    }
                }
            });





            // Construct the order by string

            $orderByString = '';

            foreach ($orderBy as $column => $direction) {

                $orderByString .= "$column $direction, ";
            }

            $orderByString = rtrim($orderByString, ', ');



            return $query->orderByRaw($orderByString)->get();
        } catch (\Exception $e) {

            Log::error("Error in MenuRepository.getByWhere(): " . $e->getMessage());

            throw $e;
        }
    }
}
