<?php



namespace App\Repository\Eloquent;




use App\Models\OrderMaster;
use App\Models\OrderItem;
use Illuminate\Contracts\Cache\Repository as Cache;

use Illuminate\Support\Facades\Log;

// use App\Models\NotificationModel;

use DB;



class OrderRepository extends BaseRepository

{



    protected $model;

    protected $cache;
    protected $chefmodel;
    protected  $bankmodel;
    protected $orderitemmodel;


    public function __construct(

        OrderMaster $model,
        OrderItem $orderitemmodel,
        Cache $cache,



    ) {

        $this->model = $model;
        $this->orderitemmodel = $orderitemmodel;

        parent::__construct($model, $cache);
    }

    //its a create function used insert data 

    public function create($allData)

    {

        try {

            return $this->model->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in OrderRepository.create(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }

    public function createOrderItems($allData)
    {
        try {

            return $this->orderitemmodel->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in OrderRepository.create(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }


    public function update($byWhere, $update)

    {

        try {

            return $this->model->where($byWhere)->update($update);
        } catch (\Exception $e) {

            Log::error("Error in OrderRepository.create(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }



    public function getOne($byWhere)

    {

        try {

            $data = $this->model->with('orderItems.menu.foodtype', 'orderItems.menu.type', 'user', 'chef')->select('*')->where($byWhere)->first();

            return $data;
        } catch (\Exception $e) {

            Log::error("Error in OrderRepository.getUser(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }





    public function getAll()

    {

        try {

            return $this->model->with('orderItems.menu.foodtype', 'orderItems.menu.type', 'user', 'chef')->orderBy('id', 'desc')->get();
        } catch (\Exception $e) {

            Log::error("Error in OrderRepository.userList(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function getAllbySearch($user, $status = null, $perPage = null)
    {
        
        try {
            $query = $this->model->with('orderItems.menu.foodtype', 'orderItems.menu.type', 'user', 'chef')
                ->orderBy('updated_at', 'desc'); ;

            // Filter by user type
            if ($user->user_type == 2) {
                $query->where('chef_id', $user->id);
            } else {
                $query->where('user_id', $user->id);
            }

            // Handle status filtering
            if ($status !== null) {
                
                if (is_string($status)) {
                    $status = explode(',', $status); 
                }
               
                if (is_array($status)) {
                    $status = array_map('intval', $status);
                    // dd($status);
                    $query->whereIn('status', $status);
                } else {
                    $validStatuses = [0, 1, 2, 3, 4, 5,6]; // All valid statuses
                    if (in_array($status, $validStatuses)) {
                        $query->where('status', $status);
                    }
                }
            }

            // Use paginate or get based on perPage value
            return $perPage ? $query->paginate($perPage) : $query->get();
        } catch (\Exception $e) {
            Log::error("Error in OrderRepository.getAll(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }






    public function delete($byWhere)

    {

        try {

            return $this->model->where($byWhere)->delete();
        } catch (\Exception $e) {

            Log::error("Error in OrderRepository.deleteData(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }





    public function getByWhere($byWhere, $perpage = null,$orderBy = ['id' => 'desc'])
    {
        try {
            $query = $this->model->where(function ($query) use ($byWhere) {
                foreach ($byWhere as $column => $condition) {
                    if (is_array($condition)) {
                        if ($condition[0] === "IN") {
                            unset($condition[0]);
                            $query->whereIn($column, $condition);
                        } else {
                            $query->where($column, $condition[0], $condition[1]);
                        }
                    } else {
                        $query->where($column, $condition);
                    }
                }
            });
           
            // Construct the order by string only if there are order conditions
            if (!empty($orderBy)) {
                $orderByString = '';
                foreach ($orderBy as $column => $direction) {
                    $orderByString .= "$column $direction, ";
                }
                $orderByString = rtrim($orderByString, ', ');
    
                $query->orderByRaw($orderByString);
            }
          
    
            // Paginate or get the results based on $perpage
            return $perpage ? $query->paginate($perpage) : $query->get();
        } catch (\Exception $e) {
            Log::error("Error in ReportRepository.getByWhere(): " . $e->getMessage());
            throw $e;
        }
    }
}
