<?php



namespace App\Repository\Eloquent;



use App\Models\WorkPlan;
use Illuminate\Contracts\Cache\Repository as Cache;

use Illuminate\Support\Facades\Log;
use App\Models\Purchase;
// use App\Models\NotificationModel;

use DB;



class PlanRepository extends BaseRepository

{
    protected $model, $purchasemodel;

    protected $cache;
    public function __construct(

        WorkPlan $model,
        Purchase $purchasemodel,

        Cache $cache,


    ) {

        $this->model = $model;
        $this->purchasemodel = $purchasemodel;
        parent::__construct($model, $cache);
    }

    public function create($allData)

    {

        try {

            return $this->model->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.createRound(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }

    public function update($byWhere, $update)

    {

        try {

            return $this->model->where($byWhere)->update($update);
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.create(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }



    public function getOne($byWhere)

    {

        try {

            $data = $this->model->select('*')->where($byWhere)->first();

            return $data;
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.getUser(): " . $e->getMessage());

            throw $e;
        }
    }





    public function getAll()

    {

        try {

            $query = $this->model->with(['subscriptions' => function ($query) {
                $query->where('status', 1);
            }]);
            return $query->orderBy('number_of_days', 'asc')->get();

            // return $this->model->orderBy('id', 'desc')->get();
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.userList(): " . $e->getMessage());

            throw $e;
        }
    }



    public function delete($byWhere)

    {

        try {

            $model = $this->model->where($byWhere)->first();
            if ($model) {
                return $model->delete(); // This will perform a soft delete
            }
            return false;
            // return $this->model->where($byWhere)->delete();

        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.deleteData(): " . $e->getMessage());

            throw $e;
        }
    }





    public function getByWhere($byWhere, $orderBy = ['id' => 'desc'])

    {

        try {

            $query = $this->model->where(function ($query) use ($byWhere) {



                foreach ($byWhere as $column => $condition) {

                    if (is_array($condition)) {



                        if ($condition[0] === "IN") {

                            unset($condition[0]);

                            $query->whereIn($column, $condition);
                        } else {

                            $query->where($column, $condition[0], $condition[1]);
                        }
                    } else {

                        $query->where($column, $condition);
                    }
                }
            });





            // Construct the order by string

            $orderByString = '';

            foreach ($orderBy as $column => $direction) {

                $orderByString .= "$column $direction, ";
            }

            $orderByString = rtrim($orderByString, ', ');



            return $query->orderByRaw($orderByString)->get();
        } catch (\Exception $e) {

            Log::error("Error in UserRepository.getUsersByWhere(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }


    public function createPurchase($allData)

    {

        try {

            return $this->purchasemodel->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.createPurchase(): " . $e->getMessage());

            throw $e;
        }
    }

    public function getOnePurchase($byWhere)

    {

        try {

            $data = $this->purchasemodel->select('*')->with('plan')->where($byWhere)->first();

            return $data;
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.getOnePurchase(): " . $e->getMessage());

            throw $e;
        }
    }

    public function getAllPurchase($byWhere = null)

    {

        try {
            if (empty($byWhere)) {
                $data = $this->purchasemodel->with('plan', 'user')->orderBy('id', 'DESC')->get();
            } else {
                $data = $this->purchasemodel->select('*')->with('plan')->where($byWhere)->orderBy('id', 'DESC')->get();
                // $data = $this->purchasemodel->select('*')->with('plan')->where($byWhere)->orderByRaw('(status = 1) DESC, id DESC')->get();
            }

            return $data;
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.getOnePurchase(): " . $e->getMessage());

            throw $e;
        }
    }

    public function getByWherePurchase($byWhere, $orderBy = ['id' => 'desc'],$perpage = null)

    {

        try {

            $query = $this->purchasemodel->where(function ($query) use ($byWhere) {



                foreach ($byWhere as $column => $condition) {

                    if (is_array($condition)) {



                        if ($condition[0] === "IN") {

                            unset($condition[0]);

                            $query->whereIn($column, $condition);
                        } else {

                            $query->where($column, $condition[0], $condition[1]);
                        }
                    } else {

                        $query->where($column, $condition);
                    }
                }
            });





            // Construct the order by string

            $orderByString = '';

            foreach ($orderBy as $column => $direction) {

                $orderByString .= "$column $direction, ";
            }

            $orderByString = rtrim($orderByString, ', ');

            if ($perpage) {
                return $query->orderByRaw($orderByString)->paginate($perpage);
            } else {
                return $query->orderByRaw($orderByString)->get();
            }
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.getByWherePurchase(): " . $e->getMessage());

            throw $e;
        }
    }


    public function Purchaseupdate($byWhere, $update)

    {

        try {

            return $this->purchasemodel->where($byWhere)->update($update);
        } catch (\Exception $e) {

            Log::error("Error in PlanRepository.create(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }
}
