<?php

namespace App\Repository\Eloquent;

use App\Models\Report;
use Illuminate\Contracts\Cache\Repository as Cache;
use Illuminate\Support\Facades\Log;
use Carbon\Carbon;



class ReportRepository extends BaseRepository
{

    protected $model;
    protected $cache;
    public function __construct(Report $model, Cache $cache)
    {
        $this->model = $model;
        parent::__construct($model, $cache);
    }

    public function create($allData)

    {
        try {

            return $this->model->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in ReportRepository.create(): " . $e->getMessage());

            throw $e;
        }
    }
    public function getOne($byWhere)
    {

        try {
            return $this->model->where($byWhere)->with('chef')->first();
        } catch (\Exception $e) {
            Log::error("Error in ReportRepository.getOne(): " . $e->getMessage());
            throw $e;
        }
    }

    public function getAll()
    {

        try {
            return $this->model->with('chef', 'user')->orderBy('id', 'desc')->get();
        } catch (\Exception $e) {
            Log::error("Error in ReportRepository.getAll(): " . $e->getMessage());
            throw $e;
        }
    }

    public function getByWhere($byWhere, $orderBy = ['created_at' => 'desc'], $perpage = null)
    {
        try {
            $query = $this->model->with('chef', 'user')->where(function ($query) use ($byWhere) {
                foreach ($byWhere as $column => $condition) {
                    if (is_array($condition)) {
                        if ($condition[0] === "IN") {
                            unset($condition[0]);
                            $query->whereIn($column, $condition);
                        } else {
                            $query->where($column, $condition[0], $condition[1]);
                        }
                    } else {
                        $query->where($column, $condition);
                    }
                }
            });
           
            // Construct the order by string only if there are order conditions
            if (!empty($orderBy)) {
                $orderByString = '';
                foreach ($orderBy as $column => $direction) {
                    $orderByString .= "$column $direction, ";
                }
                $orderByString = rtrim($orderByString, ', ');
    
                $query->orderByRaw($orderByString);
            }
          
    
            // Paginate or get the results based on $perpage
            return $perpage ? $query->paginate($perpage) : $query->get();
        } catch (\Exception $e) {
            Log::error("Error in ReportRepository.getByWhere(): " . $e->getMessage());
            throw $e;
        }
    }
    

    public function delete($byWhere)

    {

        try {

            return $this->model->where($byWhere)->delete();
        } catch (\Exception $e) {

            Log::error("Error in ReportRepository.delete(): " . $e->getMessage());

            throw $e;
        }
    }

    
}
