<?php



namespace App\Repository\Eloquent;



use App\Models\Review;
use Illuminate\Contracts\Cache\Repository as Cache;

use Illuminate\Support\Facades\Log;

// use App\Models\NotificationModel;

use DB;



class ReviewRepository extends BaseRepository

{
    protected $model;

    protected $cache;
    public function __construct(

        Review $model,

        Cache $cache,


    ) {

        $this->model = $model;
        parent::__construct($model, $cache);
    }

    public function create($allData)

    {
        // dd($allData);


        try {

            return $this->model->create($allData);
        } catch (\Exception $e) {

            Log::error("Error in ReviewRepository.create(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }

    public function update($byWhere, $update)

    {

        try {

            return $this->model->where($byWhere)->update($update);
        } catch (\Exception $e) {

            Log::error("Error in ReviewRepository.update(): " . $e->getMessage());

            throw $e;

            // return response()->json(['status' => '0', 'message' => __('message.statusZero')]);

        }
    }



    public function getOne($byWhere)

    {

        try {

            $data = $this->model->select('*')->where($byWhere)->first();

            return $data;
        } catch (\Exception $e) {

            Log::error("Error in ReviewRepository.getOne(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }





    public function getAll()

    {

        try {

            return $this->model->with('user')->orderBy('id', 'desc')->get();
        } catch (\Exception $e) {

            Log::error("Error in ReviewRepository.getAll(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }



    public function delete($byWhere)

    {

        try {

            $model = $this->model->where($byWhere)->first();
            if ($model) {
                return $model->delete(); // This will perform a soft delete
            }
            return false;
            // return $this->model->where($byWhere)->delete();

        } catch (\Exception $e) {

            Log::error("Error in ReviewRepository.delete(): " . $e->getMessage());

            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }





    public function getByWhere($byWhere, $orderBy = ['id' => 'desc'], $perPage = null)
    {
        try {
            $query = $this->model->with('user', 'user.chefDetail')->where(function ($query) use ($byWhere) {
                foreach ($byWhere as $column => $condition) {
                    if (is_array($condition)) {
                        if ($condition[0] === "IN") {
                            unset($condition[0]);
                            $query->whereIn($column, $condition);
                        } else {
                            $query->where($column, $condition[0], $condition[1]);
                        }
                    } else {
                        $query->where($column, $condition);
                    }
                }
            });

            // Construct the order by string
            $orderByString = '';
            foreach ($orderBy as $column => $direction) {
                $orderByString .= "$column $direction, ";
            }
            $orderByString = rtrim($orderByString, ', ');

            // Use pagination if $perPage is specified, otherwise get all records
            if ($perPage) {
                return $query->orderByRaw($orderByString)->paginate($perPage);
            } else {
                return $query->orderByRaw($orderByString)->get();
            }
        } catch (\Exception $e) {
            Log::error("Error in ReviewRepository.getByWhere(): " . $e->getMessage());
            return response()->json(['status' => '0', 'message' => __('message.statusZero')]);
        }
    }

    public function getReviewCount($chefId)
    {
        try {

            return $this->model->where('chef_id', $chefId)->count();
        } catch (\Exception $e) {

            Log::error("Error in ReviewRepository.getReviewCount(): " . $e->getMessage());

            throw $e;
        }
    }

    public function getAverageRating($chefId)
    {
        try {

            $averageRating = $this->model->where('chef_id', $chefId)->avg('rating');
            return $averageRating !== null ? $averageRating : 0;
        } catch (\Exception $e) {

            Log::error("Error in ReviewRepository.getAverageRating(): " . $e->getMessage());

            throw $e;
        }
    }

    public function getAverageRatingAndCount($chefId)
    {
        try {
            $ratings = $this->model->selectRaw('avg(rating) as average_rating, count(*) as total_reviews_count')
                ->where('chef_id', $chefId)
                ->first();

            return [
                'average_rating' => $ratings->average_rating !== null ? $ratings->average_rating : 0,
                'total_reviews_count' => $ratings->total_reviews_count ?? 0,
            ];
        } catch (\Exception $e) {
            Log::error("Error in ReviewRepository.getAverageRatingAndCount(): " . $e->getMessage());
            throw $e;
        }
    }
}
