<?php

namespace App\Services\Admin;

use Illuminate\Support\Facades\Hash;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Log;
use App\Repository\Eloquent\PlanRepository;
use App\Traits\UploadImageTrait;
use Exception;
use Carbon\Carbon;


class PlanServices
{

    use UploadImageTrait;

    protected $PlanRepository;
    private $dataObject;
    public function __construct(PlanRepository $PlanRepository)
    {

        $this->PlanRepository = $PlanRepository;
        $this->dataObject = new \stdClass();
    }


    public function create($request)
    {
        try {
            // dd($request);
            $data = [
                'plan_title' => $request->plan_title,
                'description' => $request->description,
                'cost' => $request->cost,
                'number_of_days' => $request->number_of_days,
                'discount_percentage' => $request->discount_percentage,
            ];
            $success = $this->PlanRepository->create($data);
            if ($success) {
                return response()->json(['message' => __('message.statusOne', ['parameter' =>  __('message.plan')]), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 201);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'),  'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error("PlanServices : create()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }



    public function update($request)
    {
        try {
            $data = [
                'plan_title' => $request->plan_title,
                'description' => $request->description,
                'cost' => $request->cost,
                'number_of_days' => $request->number_of_days,
                'discount_percentage' => $request->discount_percentage,
            ];
            $success = $this->PlanRepository->update(['id' => $request->id], $data);
            if ($success) {
                return response()->json(['message' => __('message.statusTwo', ['parameter' =>  __('message.plan')]), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 201);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'),  'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error("PlanServices : create()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function planpurchaseInsert($request)
    {
        try {
            // dd($request);
            $user = auth()->user();

            $plan_data = $this->PlanRepository->getOne(['id' => $request->plan_id]);
            $expiresAt = now()->addDays($plan_data->number_of_days)->format('Y-m-d');
            $status = 1;
            $condition = [
                'user_id' => $user->id,
                'status' => $status
            ];


            $currentPurchases = $this->PlanRepository->getOnePurchase($condition);

            if ($currentPurchases) {
                // if ($currentPurchases->expires_at > now()) {
                //     $expiresAt = Carbon::parse($currentPurchases->expires_at)->addDays($plan_data->number_of_days)->format('Y-m-d');
                //     $status = 1;
                // }
                $success = $this->PlanRepository->Purchaseupdate(['id' => $currentPurchases->id], ['status' => 0]);
                $status = 1;

            }
            $randomNo = rand(10000, 99999);
            $transactionUniqueId = '#'.''.$randomNo;
            $data = [
                'transaction_unique_id' => $transactionUniqueId,
                'transaction_id' => $request->transaction_id,
                'plan_id' => $request->plan_id,
                'user_id' => $user->id,
                'status' => $status,
                'payment_method' => $request->payment_method,
                'expires_at' => $expiresAt,
                'final_amount' => $request->final_amount,
                'amount'=> $plan_data->cost,
                'discount'=> $plan_data->discount_percentage,
            ];
            // dd($data);
            if($status == 1){
                $data['from_at'] = now()->format('Y-m-d');
            }
            $success = $this->PlanRepository->createPurchase($data);
            $latestdata = $this->PlanRepository->getOnePurchase(['id' => $success->id]);
            if ($success) {
                if($success->status == 1){
                    User::where('id', $user->id)->update([
                        'plan_id' => $request->plan_id,
                        'subscription_id' => $success->id 
                    ]);
                }
                return response()->json(['message' => __('message.Purchase'), 'data' => $latestdata, 'status' => 1, 'error' => $this->dataObject], 201);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'),  'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error("PlanServices : create()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }
}
