<?php



namespace App\Services\Users;



use Illuminate\Support\Facades\Log;

use App\Repository\Eloquent\{FavouriteRepository};
use Illuminate\Support\Facades\Hash;

use Illuminate\Support\Facades\File;

use Illuminate\Support\Facades\Mail;

use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Auth;

use Illuminate\Support\Str;

use App\Traits\UploadImageTrait;

use App\Http\Requests\Api\FavoriteRequest;
use App\Http\Requests\Api\ReviewRequest;
use App\Models\Favorite;
use App\Services\Users\UserServices;
use App\Repository\Eloquent\MenuRepository;

use Exception;
use App\Models\Review;
use Illuminate\Support\Facades\Validator;

class FavouriteServices

{
    use UploadImageTrait;

    protected $FavouriteRepository;
    protected $UserServices;
    private $dataObject;
    protected $MenuRepository;

    public function __construct(MenuRepository $MenuRepository,FavouriteRepository $FavouriteRepository, UserServices $UserServices)
    {
        $this->FavouriteRepository = $FavouriteRepository;
        $this->UserServices = $UserServices;
        $this->MenuRepository = $MenuRepository;
        $this->dataObject = new \stdClass();
    }

    public function addToFavorite($request)
    {
        // dd($request);
        try {
            $user = auth()->user();
            $value = [
                'menu_id' => $request->menu_id,
                'user_id' => $user->id,
            ];

            $getdata = $this->FavouriteRepository->getOne($value);
            
            if ($getdata) {
                return response()->json(['message' => __('message.favourite_already'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
            $data = $this->FavouriteRepository->create($value);

            if ($data) {
                // $datas = $this->MenuRepository->update(['id' => $request->menu_id], ['is_favorite' => 1]);
               
                $this->updateMenuFavorites($request->menu_id, 1);

                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function myFavoriteList($request)
    {
        try {
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }
            $condition=[
                'user_id' => $user->id,
            ];
            if (!empty($request->keyword)) {
                $keyword = $request->keyword;
                $data = $this->FavouriteRepository->getByWhere($condition, [], $request->limit ?? 10, $keyword);
            } else {
                $data = $this->FavouriteRepository->getByWhere($condition, [], $request->limit ?? 10);
            }
            if (isset($data) && !empty($data)) {
                foreach ($data as $value) {
                    // dd($value->menu->upload_images);
                    $value->menu->upload_images = json_decode($value->menu->upload_images);
                    $value->menu->is_favorite = 1;
                }

                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function removeFromFavorite($request)
    {
        try {
            $user = auth()->user();
            $condition = [
                'menu_id' => $request->menu_id,
                'user_id' => $user->id,
            ];
            $success = $this->FavouriteRepository->delete($condition);

            if ($success) {
                $this->updateMenuFavorites($request->menu_id, -1);

                return response()->json(['message' => __('message.statusThree', ['parameter' => 'Favorite']), 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.favorite_not_found'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    private function updateMenuFavorites($menuId, $increment)
    {
        $menu = $this->MenuRepository->getOne(['id' => $menuId]);
        // dd($menu);
        if ($menu) {
            $menu->increment('favourite_count', $increment);
          
        }
    }

   
}
