<?php



namespace App\Services\Users;



use Illuminate\Support\Facades\Log;

use App\Repository\Eloquent\{MenuRepository};
use Illuminate\Support\Facades\Hash;

use Illuminate\Support\Facades\File;

use Illuminate\Support\Facades\Mail;

use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Auth;

use Illuminate\Support\Str;
use App\Models\Category;
use App\Traits\UploadImageTrait;

use App\Http\Requests\Api\FavoriteRequest;
use App\Http\Requests\Api\ReviewRequest;
use App\Models\Favorite;
use App\Services\Users\UserServices;
use Exception;
use App\Models\Menu;
use Illuminate\Support\Facades\Validator;

class MenuServices

{
    use UploadImageTrait;

    protected $MenuRepository;
    private $dataObject;

    public function __construct(MenuRepository $MenuRepository)
    {
        $this->MenuRepository = $MenuRepository;
        $this->dataObject = new \stdClass();
    }

    public function menuAdd($request)
    {

        try {
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }
            $value['user_id'] = $user->id;
            $value['item_name'] = $request->item_name;
            if (!empty($request->upload_images)) {
                $value['upload_images'] = json_encode($request->upload_images, JSON_UNESCAPED_SLASHES);
            }
            // $value['upload_images'] = json_encode($request->upload_images);
            $value['price'] = $request->price;
            $value['category_id'] = json_encode($request->category_id);
            $value['minimum_deposit'] = $request->minimum_deposit;
            $value['type_id'] = $request->type_id;
            $value['preparation_notice'] = $request->preparation_notice;
            $value['detail'] = $request->detail;
            $value['preparation_time'] = $request->preparation_time;
            $value['foodtype_id'] = $request->foodtype_id;
            // dd($value);
            $data = $this->MenuRepository->create($value);
            if ($data) {
                return response()->json(['message' => __('message.statusOne', ['parameter' => __('message.menu')]), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function menuEdit($request)
    {
        try {
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }
            $value['user_id'] = $user->id;

            if ($request->item_name) {
                $value['item_name'] = $request->item_name;
            }
            if (!empty($request->upload_images)) {
                $value['upload_images'] = json_encode($request->upload_images, JSON_UNESCAPED_SLASHES);
            }
            if ($request->price) {
                $value['price'] = $request->price;
            }
            if ($request->category_id) {
                $value['category_id'] = json_encode($request->category_id);
            }
            if ($request->minimum_deposit) {
                $value['minimum_deposit'] = $request->minimum_deposit;
            }
            if ($request->type_id) {
                $value['type_id'] = $request->type_id;
            }
            if ($request->preparation_notice) {
                $value['preparation_notice'] = $request->preparation_notice;
            }
            if ($request->detail) {
                $value['detail'] = $request->detail;
            }
            if ($request->preparation_time) {
                $value['preparation_time'] = $request->preparation_time;
            }
            if ($request->foodtype_id) {
                $value['foodtype_id'] = $request->foodtype_id;
            }
            $data = $this->MenuRepository->update(['id' => $request->id], $value);
            if ($data) {
                $datas = $this->MenuRepository->getOne(['id' => $request->id]);

                return response()->json(['message' => __('message.statusTwo', ['parameter' => __('message.menu')]), 'data' => $datas, 'status' => 1, 'error' => $this->dataObject], 200);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'), 'data' => $this->dataObject, 'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function menuList($request)
    {
        try {
            $limit = $request->limit ?? 10;
            $user = auth()->user();
            if (!$user) {
                return response()->json(['error' => 'Unauthorized'], 401);
            }
    
            // Join the users table to get lat/lng values
            // $query = Menu::with('type', 'user', 'foodtype','user.chefDetail')
            //     ->join('users', 'menus.user_id', '=', 'users.id') // Join the users table
            //     ->select('menus.*'); // Select only the columns from menus
            $query = Menu::with('type', 'user', 'foodtype', 'user.chefDetail')
            ->leftJoin('favorites', function($join) use ($user) {
                $join->on('menus.id', '=', 'favorites.menu_id')
                     ->where('favorites.user_id', '=', $user->id);
            })
            ->leftJoin('chef_detail as cd', 'menus.user_id', '=', 'cd.user_id') // Correct join alias for chef_details
            ->select('menus.*', 'cd.average_rating', DB::raw('IF(favorites.id IS NOT NULL, 1, 0) AS is_favorite'));

            // Apply filters based on request parameters
            if (isset($request->keyword)) {
                $query->where('item_name', 'like', '%' . $request->keyword . '%');
            }
    
            if (isset($request->category_id)) {
                $categories = explode(',', $request->category_id);
                if (is_array($categories) && !empty($categories)) {
                    $query->where(function($q) use ($categories) {
                        foreach ($categories as $categorie) {
                            $categorie = trim($categorie); // Remove any whitespace
                            $q->orWhereJsonContains('category_id', (int)$categorie); // Assuming categories are integers
                        }
                    });
                }
            }
    
            if (!empty($request->has('food_type'))) {
                $query->where('foodtype_id', $request->food_type); // Filter by foodtype_id
            }
    
            if (!empty($request->chef_name)) {
                $query->whereHas('user', function ($q) use ($request) {
                    $q->where('name', 'like', '%' . $request->chef_name . '%');
                });
            }

            if (!empty($request->chef_id)) {
                $query->whereHas('user', function ($q) use ($request) {
                    $q->where('id', $request->chef_id);
                });
            }
    
            if (isset($request->food_name)) {
                $query->where('item_name', 'like', '%' . $request->food_name . '%');
            }
    
            if (!empty($request->type_id)) {
                $query->where('type_id', $request->type_id); 
            }
    
            if (!empty($request->max_price)) {
                $query->where('price', '<=', $request->max_price);
            }
            if (!empty($request->min_price)) {
                $query->where('price', '>=', $request->min_price);
            }
    
            if (!empty($request->min_rating)) {
                $query->where('cd.average_rating', '>=', $request->min_rating);
            }
    
            // Latitude and Longitude Filter
            if (!empty($request->lat) && !empty($request->lng)) {
            
                $lat = $request->lat;
                $lng = $request->lng;
                // dd($lat, $lng);
                $userId = $user->id;
                $query->select(
                    'menus.*',
                    DB::raw("(6371 * acos(
                        cos(radians(".$lat.")) 
                        * cos(radians(users.lat)) 
                        * cos(radians(users.lng) - radians(".$lng."))
                       + sin(radians(".$lat.")) 
                        * sin(radians(users.lat))
                    )) as distance")
                )
                ->join('users', 'menus.user_id', '=', 'users.id');
                
                // $query->select(
                //     'menus.*',
                //     DB::raw('(6371 * acos(
                //         cos(radians(' . $lat . ')) 
                //         * cos(radians(users.lat)) 
                //         * cos(radians(users.lng) - radians(' . $lng . ')) 
                //         + sin(radians(' . $lat . ')) 
                //         * sin(radians(users.lat))
                //     )) as distance')
                // );
                // dd($query);
            }
    
            // Filter by distance
            if (!empty($request->min_distance)) {
                $query->having('distance', '>=', $request->min_distance);
            }
            if (!empty($request->max_distance)) {
                $query->having('distance', '<=', $request->max_distance);
            }
    
            // Execute the query and paginate results
            $data = $query->orderBy('menus.id', 'desc')->paginate((int) $limit);
    
            // Check if data is empty and return a specific message
            if ($data->isEmpty()) {
                return response()->json([
                    'message' =>  __('message.no_data_found'),
                    'status' => 0,
                    'data' => [],
                ], 404);
            }
    
            // Return the results if found
            foreach ($data as $value) {
                $value->upload_images = json_decode($value->upload_images);
            }

            foreach ($data as $item) {
             
                $categoryIds = json_decode($item->category_id, true); 
                if (!empty($categoryIds)) {
                    $categories = Category::whereIn('id', $categoryIds)->get();
                    $item->category_names = $categories; 
                }
            }
            
            return response()->json([
                'message' => __('message.success'),
                'data' => $data,
                'status' => 1,
                'error' => $this->dataObject,
            ], 200);
    
        } catch (Exception $e) {
            Log::error("Error in MenuServices.menuList(): " . $e->getMessage());
            return response()->json(['message' => __('message.some_thing_went_wrong'), 'status' => 0, 'data' => []], 500);
        }
    }
    
    
}
