<?php



namespace App\Services\Users;



use Illuminate\Support\Facades\Log;

use App\Repository\Eloquent\OrderRepository;
use Illuminate\Support\Facades\Hash;

use Illuminate\Support\Facades\File;

use Illuminate\Support\Facades\Mail;

use Illuminate\Support\Facades\DB;

use Illuminate\Support\Facades\Auth;

use App\Models\OrderMaster;
use App\Models\OrderItem;
use App\Traits\SendNotificationTrait;

use App\Http\Requests\Api\FavoriteRequest;
use App\Http\Requests\Api\ReviewRequest;
use App\Models\Favorite;
use App\Services\Users\UserServices;
use Exception;
use App\Repository\Eloquent\UserRepository;
use App\Repository\Eloquent\ReviewRepository;
use Illuminate\Support\Facades\Validator;

class OrderServices

{
    use SendNotificationTrait;
    protected $userRepository, $orderRepository, $reviewRepository;
    private $dataObject;
    public function __construct(UserRepository $userRepository, OrderRepository $orderRepository, ReviewRepository $reviewRepository)
    {
        $this->dataObject = new \stdClass();
        $this->orderRepository = $orderRepository;
        $this->userRepository = $userRepository;
        $this->reviewRepository = $reviewRepository;
    }

    public function placeOrder($data)
    {
        try {
            
            $user = auth()->user();
            
            $randomNo = rand(10000, 99999);
            $UniqueId = '#' . '' . $randomNo;
            $orderMasterData = [
                'unique_id' => $UniqueId,
                'user_id' => $user->id,
                'payment_type' => $data->payment_type,
                'instapay_email' => $data->instapay_email ?? null,
                'instapay_phone_no' => $data->instapay_phone_no ?? null,
                'bank_name' => $data->bank_name ?? null,
                'account_number' => $data->account_number ?? null,
                'branch_name' => $data->branch_name ?? null,
                'branch_code' => $data->branch_code ?? null,
                'total_amount' => $data->total_amount,
                'total_quantity' => $data->total_quantity,
                'chef_id' => $data->chef_id
            ];
            
            $chefdata = $this->userRepository->getOne(['id' => $data->chef_id]);

            $orderMaster = $this->orderRepository->create($orderMasterData);

            $orderItems = [];
            foreach ($data->items as $menu_id => $item) {
                $orderItems = [

                    'order_master_id' => $orderMaster->id,
                    'menu_id' => $menu_id,
                    'per_item_amount' => $item['amount'],
                    'per_item_quantity' => $item['qty'],
                    'total_amount' => $item['amount'] * $item['qty'],
                ];
               
                $data = $this->orderRepository->createOrderItems($orderItems);
                
                $orderItems[] = $data;
            }
            // dd($orderItems);
            // $title = __("message.order_place");
            $notif_data = [
                "screen" => "booking",
                'order_id' => $orderMaster->id,
                'menu_id' => $orderItems['menu_id'],
                'recieved_from' => $user->id,
                'bookingId' => $orderItems['order_master_id'],
            ];
            // $body = __('message.order_received', ['order_id' => $orderMaster->unique_id]);
            // dd($body);
// dd($chefdata);
            // A new dd($chefdata->device_id);order request is received with #53435, tap to respond
            if ($chefdata->device_id) {
                
                $content['title_en'] =  __("message.order_place", [], 'en');
                 $content['title_ar'] =  __("message.order_place", [], 'ar');
                   $content['body_en'] = __('message.order_received', ['order_id' => $orderMaster->unique_id], 'en');
                     $content['body_ar'] = __('message.order_received', ['order_id' => $orderMaster->unique_id], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }
                        
                $this->userRepository->createNotification(0, $chefdata->id, $notif_data,$content);
                $this->sendPushNotification([$chefdata->device_id], $notif_title, $notif_body, $notif_data);
            }
            // dd($orderItems);  if(app()->getLocale() == 'en') {
                            //     $notif_title = $content['title_en'];
                            // }
            // dd($orderMaster);
            return response()->json(['message' => __('message.statusOne', ['parameter' => __('message.Order')]), 'data' => $orderItems, 'status' => 1, 'error' => $this->dataObject], 201);
        } catch (Exception $e) {
            Log::error("OrderServices : placeOrder()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    public function getOrder($request)
    {
        try {
            // dd($data);
            $user = auth()->user();
            $status = $request->input('status');
            $perPage = $request->input('limit', 10);

            // Pass the user to the repository method
            $data = $this->orderRepository->getAllbySearch($user, $status, $perPage);
            if ($data) {
                if (!$data->isEmpty()) {
                    foreach ($data as $order) {
                        if ($order->orderItems) {
                            foreach ($order->orderItems as $item) {
                                if ($item->menu) {

                                    $uploadImages = $item->menu->upload_images;
                                    if (is_string($uploadImages)) {
                                        $uploadImagesArray = json_decode($uploadImages, true);

                                        if (json_last_error() !== JSON_ERROR_NONE) {
                                        }
                                    } elseif (is_array($uploadImages)) {
                                        $uploadImagesArray = $uploadImages;
                                    } else {
                                        $uploadImagesArray = [];
                                    }

                                    $item->menu->upload_images = $uploadImagesArray;
                                }
                            }
                        }
                    }
                }
                return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 200);
            }

            // return response()->json(['message' => __('message.success'), 'data' => $data, 'status' => 1], 200);
        } catch (Exception $e) {
            Log::error("OrderServices : getOrder()" . $e->getLine() . " " . $e->getMessage());
            return redirect()->route('admin.dashboard')->withErrors(['error' => __('message.something_went_wrong')]);
        }
    }

    // public function editOrder($request)
    // {
    //     try {
    //         // dd($request);
    //         if (isset($request->status)) {
    //             $data['status'] = $request->status;
    //         }
    //         $run = $this->orderRepository->update(['id' => $request->id], $data);
    //         if ($run) {
    //             return response()->json(['status' => 1, 'message' => __('message.statusTwo', ['parameter' => 'Order'])]);
    //         }
    //     } catch (Exception $e) {

    //         Log::error('Error: ' . $e->getMessage());

    //         return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
    //     }
    // }
    public function editOrder($request)
    {
        
        try {
            $user = auth()->user();
            $chefdata = $this->userRepository->getOne(['id' => $request->chef_id]);
            $order_data = $this->orderRepository->getOne(['id' => $request->id]);
            $userdata = $this->userRepository->getOne(['id' => $order_data->user_id]);
            // dd($order_data);
            $data = [];

            if (isset($request->status)) {
                $data['status'] = $request->status;

                switch ($request->status) {
                    case 2: // rejected
                        if (isset($request->reason)) {
                            $data['reason'] = $request->reason;

                            // Prepare notification data for rejection
                            $notif_data = [
                                "screen" => "booking",
                                'order_id' => $order_data->id,
                                'reason' => $request->reason,
                                'recieved_from' => $user->id,
                            ];

                            $body = __('message.order_rejected', [
                                'order_id' => $order_data->unique_id,
                                'user_name' => $user->name,
                                'reason' => $request->reason,
                            ]);                            // dd($body);
                            
                            $content['title_en'] =  __("message.order_rejected_ti", [], 'en');
                 $content['title_ar'] =  __("message.order_rejected_ti", [], 'ar');
                   $content['body_en'] = __('message.order_rejected',  [
                                'order_id' => $order_data->unique_id,
                                'user_name' => $user->name,
                                'reason' => $request->reason,
                            ], 'en');
                     $content['body_ar'] = __('message.order_rejected',  [
                                'order_id' => $order_data->unique_id,
                                'user_name' => $user->name,
                                'reason' => $request->reason,
                            ], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }
                        
                // $this->userRepository->createNotification(0, $chefdata->id, $notif_data,$content);
                // $this->sendPushNotification([$chefdata->device_id], $notif_title, $notif_body, $notif_data);
                            
                            
                            // Send rejection notification
                            if ($userdata->device_id) {
                                $this->userRepository->createNotification(0, $userdata->id, $notif_data,$content);
                                $this->sendPushNotification([$userdata->device_id], $notif_title, $notif_body, $notif_data);
                            }
                        }
                        break;

                    case 1: // accepted
                    
                  
                        if (isset($request->ready_date) && isset($request->ready_time)) {
                            $data['ready_date'] = $request->ready_date;
                            $data['ready_time'] = $request->ready_time;

                            $notif_data = [
                                "screen" => "booking",
                                'order_id' => $order_data->id,
                                'ready_date' => $request->ready_date,
                                'ready_time' => $request->ready_time,
                                'recieved_from' => $user->id,
                            ];
                            // In your controller or service
                        //   $body = __('message.order_accepted', [
                        //         'order_id' => $order_data->unique_id,
                        //         'ready_date' => $request->ready_date,
                        //         'ready_time' => $request->ready_time,
                        //     ]);
                              $content['title_en'] =  __("message.order_accept_ti", [], 'en');
                 $content['title_ar'] =  __("message.order_accept_ti", [], 'ar');
                   $content['body_en'] = __('message.order_accepted', [
                                'order_id' => $order_data->unique_id,
                                'ready_date' => $request->ready_date,
                                'ready_time' => $request->ready_time,
                            ], 'en');
                     $content['body_ar'] = __('message.order_accepted', [
                                'order_id' => $order_data->unique_id,
                                'ready_date' => $request->ready_date,
                                'ready_time' => $request->ready_time,
                            ], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }

                            
                            // dd($body);

                            // $body = 'Your order (' . $order_data->unique_id . ') has been accepted and will be ready on ' . $request->ready_date . ' at ' . $request->ready_time . '.';

                            if ($userdata->device_id) {
                                $this->userRepository->createNotification(0, $userdata->id, $notif_data,$content);
                                $this->sendPushNotification([$userdata->device_id], $notif_title, $notif_body, $notif_data);
                            }
                        }
                        break;

                    case 0: // pending
                        $body = __('message.order_pending', [
                            'order_id' => $order_data->unique_id,
                        ]);
                        
                                 $content['title_en'] =  __("message.order_accept_ti", [], 'en');
                 $content['title_ar'] =  __("message.order_pending_ti", [], 'ar');
                   $content['body_en'] = __('message.order_pending', [
                            'order_id' => $order_data->unique_id,
                        ], 'en');
                     $content['body_ar'] = __('message.order_pending', [
                            'order_id' => $order_data->unique_id,
                        ], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }
                            
                            
                        if ($chefdata->device_id) {
                            $notif_data =  [
                                "screen" => "booking",
                                'order_id' => $order_data->id,
                                'recieved_from' => $user->id,
                            ];
                            $this->userRepository->createNotification(0, $chefdata->id,$notif_data,$content);
                            $this->sendPushNotification([$chefdata->device_id], $notif_title, $notif_body, $notif_data);
                        }
                        break;

                    case 3: // history
                    // dd('sdjfdsjf');
                        
                        // dd($body);
                        $content['title_en'] =  __("message.order_history_ti", [], 'en');
                 $content['title_ar'] =  __("message.order_history_ti", [], 'ar');
                   $content['body_en'] = __('message.order_history', [
                            'order_id' => $order_data->unique_id,
                        ], 'en');
                     $content['body_ar'] = __('message.order_history', [
                            'order_id' => $order_data->unique_id,
                        ], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }
                        if ($chefdata->device_id) {
                            $notif_data = [
                                "screen" => "booking",
                                'order_id' => $order_data->id,
                                'recieved_from' => $user->id,
                            ];
                            $this->userRepository->createNotification(0, $chefdata->id, $notif_data,$content);
                            $this->sendPushNotification([$chefdata->device_id], $notif_title, $notif_body, $notif_data);
                        }
                        break;

                    case 4: // ready
                        // $body = __('message.order_ready', [
                        //     'order_id' => $order_data->unique_id,
                        // ]);
                        $content['title_en'] =  __("message.order_ready_ti", [], 'en');
                 $content['title_ar'] =  __("message.order_ready_ti", [], 'ar');
                   $content['body_en'] =__('message.order_ready', [
                            'order_id' => $order_data->unique_id,
                        ], 'en');
                     $content['body_ar'] = __('message.order_ready', [
                            'order_id' => $order_data->unique_id,
                        ], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }
                        if ($userdata->device_id) {
                            $notif_data = [
                                "screen" => "booking",
                                'order_id' => $order_data->id,
                                'recieved_from' => $user->id,
                            ];
                            $this->userRepository->createNotification(0, $userdata->id, $notif_data,$content);
                            $this->sendPushNotification([$userdata->device_id],  $notif_title, $notif_body, $notif_data);
                        }
                        break;

                    case 5: // cancelled
                        // $body = __('message.order_canceled', [
                        //     'order_id' => $order_data->unique_id,
                        //     'user_name' => $user->name,
                        //     'reason' => $request->reason,
                        // ]);         
                         $content['title_en'] =  __("message.order_cancel_ti", [], 'en');
                 $content['title_ar'] =  __("message.order_cancel_ti", [], 'ar');
                   $content['body_en'] = __('message.order_canceled', [
                            'order_id' => $order_data->unique_id,
                            'user_name' => $user->name,
                            'reason' => $request->reason,
                        ], 'en');
                     $content['body_ar'] =  __('message.order_canceled', [
                            'order_id' => $order_data->unique_id,
                            'user_name' => $user->name,
                            'reason' => $request->reason,
                        ], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }
                            
                        if ($chefdata->device_id) {
                            $notif_data = [
                                "screen" => "booking",
                                'order_id' => $order_data->id,
                                'recieved_from' => $user->id,
                            ];

                        
                            $this->userRepository->createNotification(0, $chefdata->id, $notif_data,$content);
                            $this->sendPushNotification([$chefdata->device_id], $notif_title, $notif_body, $notif_data);
                        }
                        break;

                    case 6: // marked as complete
                        // $body = __('message.order_completed', [
                        //     'order_id' => $order_data->unique_id,
                        // ]);
                        
                           $content['title_en'] =  __("message.order_completed_ti", [], 'en');
                 $content['title_ar'] =  __("message.order_completed_ti", [], 'ar');
                   $content['body_en'] = __('message.order_completed', [
                            'order_id' => $order_data->unique_id,
                        ], 'en');
                     $content['body_ar'] =  __('message.order_completed', [
                            'order_id' => $order_data->unique_id,
                        ], 'ar');
                     if(app()->getLocale() == 'en') {
                                $notif_title = $content['title_en'];
                                $notif_body = $content['body_en'];
                            }else{
                                $notif_title = $content['title_ar'];
                                $notif_body = $content['body_ar'];
                            }
                            
                            
                        if ($userdata->device_id) {
                            $notif_data = [
                                "screen" => "rate_screen",
                                'order_id' => $order_data->id,
                                'recieved_from' => $user->id,
                            ];

                            $this->userRepository->createNotification(0, $userdata->id, $notif_data,$content);
                            $this->sendPushNotification([$userdata->device_id], $notif_title, $notif_body, $notif_data);
                        }
                        break;
                }
            }

            $run = $this->orderRepository->update(['id' => $request->id], $data);
            $order_data = $this->orderRepository->getOne(['id' => $request->id]);
            if ($run) {
                return response()->json(['status' => 1, 'message' => __('message.statusTwo', ['parameter' => __('message.Order')]), 'data' => $order_data, 'status' => 1, 'error' => $this->dataObject], 201);
            }
        } catch (Exception $e) {
            Log::error('Error: ' . $e->getMessage());
            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    public function addReview($request)
    {

        try {
            $user = auth()->user();
            $data = [

                'user_id' => $user->id,
                'order_id' => $request->order_id,
                'chef_id' => $request->chef_id,
                'rating' => $request->rating,
                'message' => $request->message,

            ];
            // dd($data);
            $success = $this->reviewRepository->create($data);
            if ($success) {
                if ($user->is_rate === 0) {
                    $value['is_rate'] = 1;
                    $success = $this->userRepository->update(['id' => $user->id], $value);
                }
                $this->updateReviews($request->chef_id);

                return response()->json(['message' => __('message.statusOne', ['parameter' => __('message.Review')]), 'data' => $data, 'status' => 1, 'error' => $this->dataObject], 201);
            } else {
                return response()->json(['message' => __('message.something_went_wrong'),  'status' => 0, 'error' => $this->dataObject], 400);
            }
        } catch (Exception $e) {

            Log::error('Error: ' . $e->getMessage());

            return response()->json(['error' => __('message.an_error_occured'), 'data' => $this->dataObject, 'status' => 0]);
        }
    }

    private function updateReviews($chefId)
    {
        $chef = $this->userRepository->getOne(['id' => $chefId]);

        if ($chef->chefDetail) {
            $totalReviews = $this->reviewRepository->getReviewCount($chefId);

            $averageRating = $this->reviewRepository->getAverageRating($chefId);
            // dd($averageRating);
            $chef->chefDetail->review_count = $totalReviews;
            $chef->chefDetail->average_rating = $averageRating;
            // dd($chef);
            $chef->chefDetail->save();;
        }
    }
}
