<?php
namespace App\Traits;

use Illuminate\Support\Facades\Storage;
use App\Models\AppSetting;
use Illuminate\Support\Facades\Log;
use Google\Client as GoogleClient;
use Google\Service\FirebaseCloudMessaging;


trait SendNotificationTrait
{
    
    // $notif_data = [
    //     'screen' => 'shipment',
    //     'type' => 'shipment_bid_accept',
    //     'recieved_from' => 0,
    //     'shipment_id' => $request->shipment_id,
    // ];
    // $title = __('message.shipmentawarded_title');
    // $notif_body = __('message.shipmentawarded_body');

    // $this->userRepository->createNotification(auth()->user()->id, $bid->user_id, $title, $notif_body, $notif_data);
    // $this->sendPushNotification([$user->device_id], $title, $notif_body, $notif_data);
    public function sendPushNotification($deviceIds, $title, $body, $data)
    {
        
        $status = 0;
        try {
            $project_id = AppSetting::where('key', 'firebase_project_id')->value('value');
            $project_number = AppSetting::where('key', 'firebase_project_number')->value('value');
            if (empty($project_id) || empty($project_number)) {
                Log::error("Error in Helper.sendPushNotification(): project_id,project_number=empty");
                return $status;
            }
            $accessToken = $this->getAccessToken($project_id);
            if (empty($accessToken)) {
                Log::error("Error in Helper.sendPushNotification(): accesstoken=empty");
                return $status;
            }
            if (count($deviceIds) > 1) {
                $fields = [
                    "operation" => "create",
                    "notification_key_name" => uniqid(),
                    "registration_ids" => $deviceIds
                ];
                $headers = array(
                    'Authorization: Bearer ' . $accessToken,
                    'Content-Type: application/json',
                    'access_token_auth: true',
                    'project_id: ' . $project_number
                );
                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/fcm/notification');
                curl_setopt($ch, CURLOPT_POST, true);
                curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));
                curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
                $result = curl_exec($ch);
                $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
                if (curl_errno($ch)) {
                    Log::error("Error in Helper.sendPushNotification():fcm/notification Curl error: " . curl_error($ch));
                }
                curl_close($ch);
                if ($httpcode !== 200) {
                    Log::error("Error in Helper.sendPushNotification(): multiple device get token " . $result);
                    return $status;
                } else {
                    $res = json_decode($result);
                    $deviceToken = $res->notification_key;
                }
            } else {
                $deviceToken = $deviceIds[0];
            }
            if (empty($deviceToken) || empty($title)) {
                return $status;
            }
            $fields = [
                "message" => [
                    "token" => $deviceToken,
                    "notification" => [
                        "body" => $body,
                        "title" => $title
                    ],
                    "data" => $this->integer_to_string($data)
                ]
            ];
            $headers = array(
                'Authorization: Bearer ' . $accessToken,
                'Content-Type: application/json',
            );
            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, 'https://fcm.googleapis.com/v1/projects/' . $project_id . '/messages:send');
            curl_setopt($ch, CURLOPT_POST, true);
            curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
            // curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, true);
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($fields));
            curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
            $result = curl_exec($ch);
            $httpcode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
            if (curl_errno($ch)) {
                Log::error("Error in Helper.sendPushNotification():messages:send Curl error: " . curl_error($ch));
            }
            curl_close($ch);
            if ($httpcode !== 200) {
                Log::error("Error in Helper.sendPushNotification(): messages:send result " . $result);
                $status = 0;
            } else {
                // Log::error("Error in Helper.sendPushNotification(): result " . $result);
                $result = json_decode($result);
                // print_r($result);
                if (empty($result)) {
                    $status = 0;
                } else {
                    $status = 1;
                }
                // dd($result);
            }
        } catch (Exception $e) {
            Log::error("Error in Helper.sendPushNotification(): catch " . $e->getMessage());
            throw $e;
        }
        return $status;
    }

    public function getAccessToken($project_id)
    {
        // Replace with the path to your service account JSON file
        $serviceAccountPath = base_path('config/' . $project_id . '-service-account.json');
        // dd($serviceAccountPath);
        if (empty($serviceAccountPath) || !file_exists($serviceAccountPath)) {
            return false;
        }
        try {
            // run "composer require google/apiclient" in terminal to get access token
            // Create a Google Client instance
            $client = new GoogleClient();
            // Set the authentication config from the service account file
            $client->setAuthConfig($serviceAccountPath);
            // Add the required scope for FCM messaging
            $client->addScope(FirebaseCloudMessaging::CLOUD_PLATFORM);
            // Attempt to fetch the access token
            if ($client->isAccessTokenExpired()) {
                $client->fetchAccessTokenWithAssertion();
            }
            $accessToken = $client->getAccessToken();
            // Resolve the promise with the access token
            return $accessToken['access_token'];
        } catch (Exception $e) {
            Log::error("Error in Helper.getAccessToken(): catch " . $e->getMessage());
            return false;
        }
    }

    private function integer_to_string($data)
    {
        if (is_array($data)) {
            foreach ($data as $key => $value) {
                $data[$key] = (string) $value;
            }
        } else {
            $data = (string) $data;
        }
        return $data;
    }
}
