@extends('admin.layouts.master')

@section('title', 'Active Chef user')

@section('content')
<style>
  table.dataTable th.dt-center,
  table.dataTable td.dt-center,
  table.dataTable td.dataTables_empty {
    text-align: center;
    display: table-cell;
    width: 100%;
  }
</style>
<section class="section">
  <div class="section-header">
    <h1>Active Chef user</h1>
  </div>
  <div class="row">
    <div class="col-lg-12 col-md-6 col-sm-6 col-12">
      <div class="card card-statistic-1">
        <table id="usersTable" class="table table-striped">
          <thead>
            <tr>
              <th>S.no</th>
              <th width="40px !important">Name</th>
              <th>Email</th>
              <th>Profile Image</th>
              <th>Mobile</th>
              <!-- <th>Plan</th> -->
              <th>Chef Referred Code</th>
              <!-- <th>Final Amount</th> -->
              <!-- <th>Plan Started From</th>
              <th>Plan Expires At</th> -->
              <th>Status</th>
              <th>Action</th>
            </tr>
          </thead>
          <tbody>
            @foreach ($activeUsers as $key=>$user)
            <tr>
              <td>{{ $key+1 }}</td>
              <td class="text-nowrap">{{ $user->name }}</td>
              <td>{{ $user->email }}</td>
              <td>
                @if($user->profile_image)
                <img src="{{ asset('storage/' .  $user->profile_image) }}" alt="Profile Image" width="50">
                @endif
              </td>

              <td>+{{ $user->phone_code }}{{ $user->phone_no }}</td>

              <!-- <td>{{ $user->plan->plan_title ?? '-' }}</td> -->
              <td>{{ $user->chef_refferal_code }}</td>
              <!-- <td>${{ $user->purchase->final_amount ?? '0'}}</td> -->
              <!-- <td>{{ $user->purchase ? \Carbon\Carbon::parse($user->purchase->from_at)->format('Y-m-d') : '-' }}
              </td>
              <td>{{ $user->purchase ? \Carbon\Carbon::parse($user->purchase->expires_at)->format('Y-m-d') : '-' }}
              </td> -->
              <td>
                {{ $user->user_status == 1 ? 'Active' : ($user->user_status == 2 ? 'Blocked' : '') }}
              </td>
              <td>
                @if($user->user_status == 1)
                <button class="btn btn-warning block-btn" data-id="{{ $user->id }}">Block</button>
                @elseif($user->user_status == 2)
                <button class="btn btn-success unblock-btn" data-id="{{ $user->id }}">Unblock</button>
                @endif
                <a href="{{ route('admin.userdetail', $user->id) }}" class="btn btn-primary">View</a>
                <div class="form-check form-switch d-inline-block">
                  <input type="checkbox" class="form-check-input toggle-featured-checkbox"
                    data-id="{{ $user->id }}"
                    {{ $user->is_featured ? 'checked' : '' }}>
                  <label class="form-check-label" for="featuredCheckbox{{ $user->id }}">
                    Featured
                  </label>
                </div>
              </td>
            </tr>
            @endforeach
          </tbody>
        </table>
      </div>

    </div>

  </div>
</section>
@endsection

@section('page_js')

<script>
  $(document).ready(function() {
    $('#usersTable').DataTable({
      "paging": true,
      "searching": true,
      "lengthChange": true,
      "pageLength": 10,
      "language": {
        "search": "Search Chef user:",
        "lengthMenu": "Display _MENU_ user per page"
      }
    });

    $('.block-btn').on('click', function() {
      var userId = $(this).data('id');
      var $button = $(this);
      var url = '{{ route("admin.users.block", ":id") }}'; // Dynamic URL template for block
      url = url.replace(':id', userId); // Replace placeholder with actual user ID
      var blockText = 'Are you sure you want to block this user?';

      $button.prop('disabled', true);

      Swal.fire({
        title: 'Are you sure?',
        text: blockText,
        icon: 'warning',
        showCancelButton: true,
        confirmButtonText: 'Yes, block!',
        cancelButtonText: 'No, cancel!',
        reverseButtons: true
      }).then((result) => {
        if (result.isConfirmed) {
          $.ajax({
            url: url,
            type: 'POST',
            data: {
              _token: $('meta[name="csrf-token"]').attr('content') // CSRF token
            },
            success: function(response) {
              Swal.fire(
                'Blocked!',
                response.message,
                'success'
              ).then(() => {
                location.reload(); // Optionally reload the page
              });
            },
            error: function(xhr) {
              console.log(xhr.responseText);
              Swal.fire(
                'Error!',
                'Something went wrong.',
                'error'
              );
            }
          }).always(function() {
            $button.prop('disabled', false);
          });
        } else {
          $button.prop('disabled', false);
        }
      });
    });

    // Unblock button click event
    $('.unblock-btn').on('click', function() {
      var userId = $(this).data('id');
      var $button = $(this);
      var url = '{{ route("admin.users.unblock", ":id") }}'; // Dynamic URL template for unblock
      url = url.replace(':id', userId); // Replace placeholder with actual user ID
      var unblockText = 'Are you sure you want to unblock this user?';

      $button.prop('disabled', true);

      Swal.fire({
        title: 'Are you sure?',
        text: unblockText,
        icon: 'warning',
        showCancelButton: true,
        confirmButtonText: 'Yes, unblock!',
        cancelButtonText: 'No, cancel!',
        reverseButtons: true
      }).then((result) => {
        if (result.isConfirmed) {
          $.ajax({
            url: url,
            type: 'POST',
            data: {
              _token: $('meta[name="csrf-token"]').attr('content') // CSRF token
            },
            success: function(response) {
              Swal.fire(
                'Unblocked!',
                response.message,
                'success'
              ).then(() => {
                location.reload(); // Optionally reload the page
              });
            },
            error: function(xhr) {
              console.log(xhr.responseText);
              Swal.fire(
                'Error!',
                'Something went wrong.',
                'error'
              );
            }
          }).always(function() {
            $button.prop('disabled', false);
          });
        } else {
          $button.prop('disabled', false);
        }
      });
    });


    $('.toggle-featured-checkbox').on('change', function() {
        var userId = $(this).data('id');
        var isFeatured = $(this).is(':checked') ? 1 : 0; // Get the checkbox state
        var url = '{{ route("admin.users.toggleFeatured", ":id") }}'; // Dynamic URL template
        url = url.replace(':id', userId); // Replace placeholder with actual user ID

        // Optional: Show loading state or disable the checkbox temporarily
        $(this).prop('disabled', true);

        $.ajax({
            url: url,
            type: 'POST',
            data: {
                _token: $('meta[name="csrf-token"]').attr('content'), // CSRF token
                is_featured: isFeatured
            },
            success: function(response) {
                Swal.fire(
                    'Success!',
                    response.message,
                    'success'
                ).then(() => {
                    location.reload(); 
                });
            },
            error: function(xhr) {
                console.log(xhr.responseText);
                Swal.fire(
                    'Error!',
                    'Failed to update featured status.',
                    'error'
                );
                // Revert checkbox state in case of error
                $(this).prop('checked', !isFeatured);
            }
        }).always(function() {
            $(this).prop('disabled', false); // Re-enable the checkbox
        });
    });

  });
</script>
@endsection