@extends('admin.layouts.master')

@section('title', 'Active Client')

@section('content')
<section class="section">
    <div class="section-header">
        <h1>Active Client</h1>
    </div>
    <div class="row">
        <div class="col-lg-12 col-md-6 col-sm-6 col-12">
            <div class="card card-statistic-1">
                <table id="usersTable" class="table table-striped">
                    <thead>
                        <tr>
                            <th>S.no</th>
                            <th>Name</th>
                            <th>Email</th>
                            <th>Profile Image</th>
                            <th>Mobile</th>
                            <th>Chef Referred Code</th>
                            <th>Status</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($activeUsers as $key=>$user)
                        <tr id="user-{{ $user->id }}">
                            <td>{{ $key+1 }}</td>
                            <td>{{ $user->name }}</td>
                            <td>{{ $user->email }}</td>
                            <td>
                                @if($user->profile_image)
                                <img src="{{ asset('storage/' .  $user->profile_image) }}" alt="Profile Image" width="50">
                                @endif
                            </td>
                            <td>+{{ $user->phone_code }}{{ $user->phone_no }}</td>
                            <td>{{ $user->refferal_code }}</td>
                            <td>
                                {{ $user->user_status == 1 ? 'Active' : ($user->user_status == 2 ? 'Blocked' : '') }}
                            </td>
                            <td>
                                @if($user->user_status == 1)
                                <button class="btn btn-warning block-btn" data-id="{{ $user->id }}">Block</button>
                                @elseif($user->user_status == 2)
                                <button class="btn btn-success unblock-btn" data-id="{{ $user->id }}">Unblock</button>
                                @endif
                                <a href="{{ route('admin.userdetail', $user->id) }}" class="btn btn-primary">View</a>
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>

        </div>

    </div>
</section>
@endsection

@section('page_js')

<script>
 $(document).ready(function() {
    $('#usersTable').DataTable({
        "paging": true,
        "searching": true,
        "lengthChange": true,
        "pageLength": 10,
        "language": {
            "search": "Search Client:",
            "lengthMenu": "Display _MENU_ store per page"
        }
    });

    $('.block-btn').on('click', function() {
      var userId = $(this).data('id');
      var $button = $(this);
      var url = '{{ route("admin.users.block", ":id") }}'; // Dynamic URL template for block
      url = url.replace(':id', userId); // Replace placeholder with actual user ID
      var blockText = 'Are you sure you want to block this user?';

      $button.prop('disabled', true);

      Swal.fire({
        title: 'Are you sure?',
        text: blockText,
        icon: 'warning',
        showCancelButton: true,
        confirmButtonText: 'Yes, block!',
        cancelButtonText: 'No, cancel!',
        reverseButtons: true
      }).then((result) => {
        if (result.isConfirmed) {
          $.ajax({
            url: url,
            type: 'POST',
            data: {
              _token: $('meta[name="csrf-token"]').attr('content') // CSRF token
            },
            success: function(response) {
              Swal.fire(
                'Blocked!',
                response.message,
                'success'
              ).then(() => {
                location.reload(); // Optionally reload the page
              });
            },
            error: function(xhr) {
              console.log(xhr.responseText);
              Swal.fire(
                'Error!',
                'Something went wrong.',
                'error'
              );
            }
          }).always(function() {
            $button.prop('disabled', false);
          });
        } else {
          $button.prop('disabled', false);
        }
      });
    });

    // Unblock button click event
    $('.unblock-btn').on('click', function() {
      var userId = $(this).data('id');
      var $button = $(this);
      var url = '{{ route("admin.users.unblock", ":id") }}'; // Dynamic URL template for unblock
      url = url.replace(':id', userId); // Replace placeholder with actual user ID
      var unblockText = 'Are you sure you want to unblock this user?';

      $button.prop('disabled', true);

      Swal.fire({
        title: 'Are you sure?',
        text: unblockText,
        icon: 'warning',
        showCancelButton: true,
        confirmButtonText: 'Yes, unblock!',
        cancelButtonText: 'No, cancel!',
        reverseButtons: true
      }).then((result) => {
        if (result.isConfirmed) {
          $.ajax({
            url: url,
            type: 'POST',
            data: {
              _token: $('meta[name="csrf-token"]').attr('content') // CSRF token
            },
            success: function(response) {
              Swal.fire(
                'Unblocked!',
                response.message,
                'success'
              ).then(() => {
                location.reload(); // Optionally reload the page
              });
            },
            error: function(xhr) {
              console.log(xhr.responseText);
              Swal.fire(
                'Error!',
                'Something went wrong.',
                'error'
              );
            }
          }).always(function() {
            $button.prop('disabled', false);
          });
        } else {
          $button.prop('disabled', false);
        }
      });
    });

  
});

</script>
@endsection