@extends('admin.layouts.master')

@section('title', 'Incoming Chef User')

@section('content')
<style>
    table.dataTable th.dt-center,
    table.dataTable td.dt-center,
    table.dataTable td.dataTables_empty {
        text-align: center;
        display: table-cell;
        width: 100%;
    }
</style>
<section class="section">
    <div class="section-header">
        <h1>Incoming Chef User</h1>
    </div>
    <div class="row">
        <div class="col-lg-12" style="padding: 1px;">
            <div class="card card-statistic-1">
                <table id="myTable" class="table table-striped">
                    <thead>
                        <tr>
                            <th>S.no</th>
                            <th>Name</th>
                            <th>Email</th>
                            <th>Profile Image</th>
                            <th>Mobile</th>
                            <th>Chef Refferal Code</th>
                            <th>Phone Verified</th>
                            <th>Email Verified</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($users as $key=>$user)
                        <tr id="user-{{ $user->id }}">
                            <td>{{ $key+1 }}</td>
                            <td>{{ $user->name }}</td>
                            <td>{{ $user->email }}</td>
                            <td>
                                @if($user->profile_image)
                                <img src="{{ asset('storage/' .  $user->profile_image) }}" alt="Profile Image" width="50">
                                @endif
                            </td>
                            <td>+{{ $user->phone_code }}{{ $user->phone_no }}</td>
                            <td>{{ $user->chef_refferal_code }}</td>
                            <td> {{ $user->phone_verified_at ? 'Yes' : 'No' }}</td>
                            <td> {{ $user->email_verified_at ? 'Yes' : 'No' }}</td>
                            <td>
                                @if($user->user_status == 0)
                                <button class="btn btn-success accept-btn" data-id="{{ $user->id }}">Accept</button>
                                <button class="btn btn-danger reject-btn" data-id="{{ $user->id }}">Reject</button>
                                @endif
                                <a href="{{ route('admin.userdetail', $user->id) }}" class="btn btn-primary">View</a>
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>

        </div>

    </div>
</section>
@endsection
@section('page_js')

<script>
  $(document).ready(function() {
    $('#myTable').DataTable({
        "paging": true,
        "searching": true,
        "lengthChange": true,
        "pageLength": 10,
        "language": {
            "search": "Search Chef:",
            "lengthMenu": "Display _MENU_ store per page"
        }
    });

    $('.accept-btn').on('click', function() {
      var userId = $(this).data('id');
      var $button = $(this);
      var url = '{{ route("admin.users.accept", ":id") }}'; // Dynamic URL template
      url = url.replace(':id', userId); // Replace placeholder with actual user ID
      var successText = 'Are you sure you want to accept this user?';

      $button.prop('disabled', true);

      Swal.fire({
        title: 'Are you sure?',
        text: successText,
        icon: 'warning',
        showCancelButton: true,
        confirmButtonText: 'Yes, proceed!',
        cancelButtonText: 'No, cancel!',
        reverseButtons: true
      }).then((result) => {
        if (result.isConfirmed) {
          $.ajax({
            url: url,
            type: 'POST',
            data: {
              _token: $('meta[name="csrf-token"]').attr('content') // CSRF token
            },
            success: function(response) {
              Swal.fire(
                'Success!',
                response.message,
                'success'
              ).then(() => {
                location.reload(); // Optionally reload the page
              });
            },
            error: function(xhr) {
              console.log(xhr.responseText);
              Swal.fire(
                'Error!',
                'Something went wrong.',
                'error'
              );
            }
          }).always(function() {
            $button.prop('disabled', false);
          });
        } else {
          $button.prop('disabled', false);
        }
      });
    });
  
    $('.reject-btn').on('click', function() {
  var userId = $(this).data('id');
  var $button = $(this);
  var url = '{{ route("admin.users.reject", ":id") }}'; // Dynamic URL template for reject
  url = url.replace(':id', userId); // Replace placeholder with actual user ID

  // Prompt for the rejection reason
  Swal.fire({
    title: 'Are you sure?',
    text: 'Please provide a reason for rejecting this user.',
    input: 'textarea', // Use textarea for the reason
    inputPlaceholder: 'Enter reason here...',
    inputAttributes: {
      'aria-label': 'Enter reason for rejection'
    },
    icon: 'warning',
    showCancelButton: true,
    confirmButtonText: 'Yes, reject!',
    cancelButtonText: 'No, cancel!',
    reverseButtons: true
  }).then((result) => {
    if (result.isConfirmed) {
      var reason = result.value; // Get the reason from the input

      if (reason) { // Check if the reason is not empty
        $button.prop('disabled', true);

        $.ajax({
          url: url,
          type: 'POST',
          data: {
            _token: $('meta[name="csrf-token"]').attr('content'), // CSRF token
            reason: reason // Send the reason with the request
          },
          success: function(response) {
            Swal.fire(
              'Rejected!',
              response.message,
              'success'
            ).then(() => {
              location.reload(); // Optionally reload the page
            });
          },
          error: function(xhr) {
            console.log(xhr.responseText);
            Swal.fire(
              'Error!',
              'Something went wrong.',
              'error'
            );
          }
        }).always(function() {
          $button.prop('disabled', false);
        });
      } else {
        Swal.fire(
          'Cancelled',
          'Rejection reason is required!',
          'info'
        );
      }
    } else {
      $button.prop('disabled', false);
    }
  });
});


    
});


</script>
@endsection