@extends('admin.layouts.master')

@section('title', 'Order list')

@section('content')
<style>
    table.dataTable th.dt-center,
    table.dataTable td.dt-center,
    table.dataTable td.dataTables_empty {
        text-align: center;
        display: table-cell;
        width: 100%;
    }
</style>
<section class="section">
    <div class="section-header">
        <h1>Order List</h1>
    </div>
    <div class="row">
        <div class="col-lg-12 col-md-6 col-sm-6 col-12">
            <div class="card card-statistic-1">
                <table id="usersTable" class="table table-striped">
                    <thead>
                        <tr>
                            <th>S.no</th>
                            <th>Order Id</th>
                            <th>Payment Type</th>
                            <th>Total Amount</th>
                            <th>Total Quantity</th>
                            <th>Status</th>
                            <th>Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        @foreach ($data as $key=>$order)
                        <tr>
                            <td>{{ $key+1 }}</td>
                            <td class="text-nowrap">{{ $order->unique_id }}</td>
                            <td>{{ $order->payment_type }}</td>
                            <td>${{ $order->total_amount }}</td>
                            <td>{{ $order->total_quantity }}</td>
                            <td>
                                {{ $order->status == 0 ? 'Pending' : ($order->status == 1 ? 'Accepted' : 
                                ($order->status == 2 ? 'Rejected' : ($order->status == 3 ? 'History' : 
                                ($order->status == 4 ? 'Ready' : 
    ($order->status == 5 ? 'Cancelled' : 
    ($order->status == 6 ? 'Marked as Complete' : 'Unknown Status')))))) }}
                            </td>
                            <td>

                                <a href="{{ route('admin.orderdetail', $order->id) }}" class="btn btn-primary">View</a>
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>

        </div>

    </div>
</section>
@endsection

@section('page_js')

<script>
    $(document).ready(function() {
        $('#usersTable').DataTable({
            "paging": true,
            "searching": true,
            "lengthChange": true,
            "pageLength": 10,
            "language": {
                "search": "Search Order:",
                "lengthMenu": "Display _MENU_ order per page"
            }
        });

        $('.block-btn').on('click', function() {
            var userId = $(this).data('id');
            var $button = $(this);
            var url = '{{ route("admin.users.block", ":id") }}'; // Dynamic URL template for block
            url = url.replace(':id', userId); // Replace placeholder with actual user ID
            var blockText = 'Are you sure you want to block this user?';

            $button.prop('disabled', true);

            Swal.fire({
                title: 'Are you sure?',
                text: blockText,
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Yes, block!',
                cancelButtonText: 'No, cancel!',
                reverseButtons: true
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        url: url,
                        type: 'POST',
                        data: {
                            _token: $('meta[name="csrf-token"]').attr('content') // CSRF token
                        },
                        success: function(response) {
                            Swal.fire(
                                'Blocked!',
                                response.message,
                                'success'
                            ).then(() => {
                                location.reload(); // Optionally reload the page
                            });
                        },
                        error: function(xhr) {
                            console.log(xhr.responseText);
                            Swal.fire(
                                'Error!',
                                'Something went wrong.',
                                'error'
                            );
                        }
                    }).always(function() {
                        $button.prop('disabled', false);
                    });
                } else {
                    $button.prop('disabled', false);
                }
            });
        });

        // Unblock button click event
        $('.unblock-btn').on('click', function() {
            var userId = $(this).data('id');
            var $button = $(this);
            var url = '{{ route("admin.users.unblock", ":id") }}'; // Dynamic URL template for unblock
            url = url.replace(':id', userId); // Replace placeholder with actual user ID
            var unblockText = 'Are you sure you want to unblock this user?';

            $button.prop('disabled', true);

            Swal.fire({
                title: 'Are you sure?',
                text: unblockText,
                icon: 'warning',
                showCancelButton: true,
                confirmButtonText: 'Yes, unblock!',
                cancelButtonText: 'No, cancel!',
                reverseButtons: true
            }).then((result) => {
                if (result.isConfirmed) {
                    $.ajax({
                        url: url,
                        type: 'POST',
                        data: {
                            _token: $('meta[name="csrf-token"]').attr('content') // CSRF token
                        },
                        success: function(response) {
                            Swal.fire(
                                'Unblocked!',
                                response.message,
                                'success'
                            ).then(() => {
                                location.reload(); // Optionally reload the page
                            });
                        },
                        error: function(xhr) {
                            console.log(xhr.responseText);
                            Swal.fire(
                                'Error!',
                                'Something went wrong.',
                                'error'
                            );
                        }
                    }).always(function() {
                        $button.prop('disabled', false);
                    });
                } else {
                    $button.prop('disabled', false);
                }
            });
        });


    });
</script>
@endsection