@extends('admin.layouts.master')

@section('title', 'Dashboard')

@push('pagetitle')
Profile Edit
@endpush

@section('content')

<section class="section">
    <div class="section-header">
        <h1>Profile</h1>
        <div class="section-header-breadcrumb">
            <div class="breadcrumb-item active"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
            <div class="breadcrumb-item">Profile</div>
        </div>
    </div>
    <div class="section-body">
        <h2 class="section-title">Hi, {{ $user->name }}</h2>
        <p class="section-lead">
            Change information about yourself on this page.
        </p>



        <div class="row mt-sm-4">
            <div class="col-12 col-md-12 col-lg-7">
                <div class="card">
                    <form id="profile-update-form" method="POST" action="{{ route('admin.profile.update') }}" enctype="multipart/form-data">
                        @csrf
                        @method('PATCH')
                        <div class="card-header">
                            <h4>Edit Profile</h4>
                        </div>
                        <div class="card-body">
                            <div class="row">
                                <div class="form-group col-md-6 col-12">
                                    <label>Name</label>
                                    <input type="text" class="form-control" name="name" value="{{ old('name', $user->name) }}">
                                    <div class="invalid-feedback name"></div>
                                </div>
                                <div class="form-group col-md-6 col-12">
                                    <label>Email</label>
                                    <input type="text" class="form-control" name="email" value="{{ old('email', $user->email) }}">
                                    <div class="invalid-feedback email"></div>
                                </div>
                                <div class="form-group col-md-12 col-12">
                                    <label>Profile Image</label>
                                    <input type="file" class="form-control" name="profile_image" id="profile-image-input" accept="image/jpeg, image/png">
                                    <div class="invalid-feedback profile_image"></div>
                                </div>
                                <!-- Image Preview for Uploaded Image -->
                                <div id="image-preview" class="mb-4 row align-items-center">
                                    <div class="col-sm-9 offset-sm-3">

                                        <img id="preview" src="{{ $user->profile_image ? asset('storage/' . $user->profile_image) : asset('assets\img\avatar\avatar-5.png') }}" alt="Image Preview" style="width: 150px; height: 150px; border-radius: 50%; object-fit: cover;">
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="card-footer text-right">
                            <button type="submit" class="btn btn-primary" id="udpate_password">Save Changes</button>
                        </div>
                    </form>
                </div>
            </div>
        </div>

    </div>
</section>

@endsection

@section('page_js')
<!-- <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script> -->
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
<script>
    $(document).ready(function() {
        // Handle form submission
        $('#profile-update-form').on('submit', function(event) {
            event.preventDefault(); // Prevent the default form submission

            // Validate required fields manually if needed
            var valid = true;
            $(this).find('[required]').each(function() {
                if (!$(this).val()) {
                    valid = false;
                    $(this).addClass('is-invalid');
                    // Optionally show a message
                    $(this).siblings('.invalid-feedback').html('This field is required.');
                } else {
                    $(this).removeClass('is-invalid');
                    $(this).siblings('.invalid-feedback').html('');
                }
            });

            if (!valid) {
                return; // Prevent form submission if validation fails
            }

            var form = $(this);
            var formData = new FormData(this); // Use FormData to handle file uploads

            $.ajax({
                url: form.attr('action'), // Form action URL
                type: 'POST', // Form submission method
                data: formData, // Form data
                processData: false, // Important for file uploads
                contentType: false, // Important for file uploads
                beforeSend: function() {
                    $("#udpate_password").prop("disabled", true);
                    $("#udpate_password").text("Process.....");
                },
                success: function(response) {
                    $("#udpate_password").prop("disabled", false);
                    $("#udpate_password").text("Save Changes");
                    if (response.success) {
                        Swal.fire({
                            icon: 'success',
                            title: 'Success!',
                            text: response.message,
                            confirmButtonText: 'OK'
                        }).then(function() {
                            var submitButton = form.find('button[type="submit"]');
                            submitButton.prop('disabled', true).text('Password Updated');
                            window.location.reload(); // Reload the page on success
                        });
                    }
                },
                error: function(xhr) {
                    $("#udpate_password").prop("disabled", false);
                    $("#udpate_password").text("Update Password");
                    // Handle error response
                    var errors = xhr.responseJSON.errors;

                    // Clear previous error messages
                    $('.invalid-feedback').empty();
                    $('.form-control').removeClass('is-invalid');

                    // Display error messages next to the relevant fields
                    $.each(errors, function(key, value) {
                        var inputField = $('input[name="' + key + '"]');
                        var errorFeedback = inputField.siblings('.invalid-feedback.' + key);
                        if (errorFeedback.length === 0) {
                            errorFeedback = $('textarea[name="' + key + '"]').siblings('.invalid-feedback.' + key);
                        }
                        if (errorFeedback.length === 0) {
                            errorFeedback = $('select[name="' + key + '"]').siblings('.invalid-feedback.' + key);
                        }
                        if (errorFeedback.length === 0) {
                            errorFeedback = $('.invalid-feedback.' + key);
                        }
                        errorFeedback.text(value[0]);
                        inputField.addClass('is-invalid');
                    });

                    $('#form-errors').show(); // Show the error container if needed
                }
            });
        });

        // Handle image preview
        $('#profile-image-input').on('change', function() {
            var file = this.files[0];
            if (file) {
                var reader = new FileReader();
                reader.onload = function(e) {
                    $('#preview').attr('src', e.target.result);
                };
                reader.readAsDataURL(file);
            } else {
                $('#preview').attr('src', '{{ $user->profile_image ? asset($user->profile_image) : asset("assets\ img\ avatar\ avatar - 5. png ") }}');
            }
        });


    });
</script>
@endsection