<?php

use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::get('/', function () {
    return view('welcome');
});
Route::get('/user-email-verify/{token}', 'App\Http\Controllers\HomeController@userEmailVerify')->name('user-email-verify');

Route::prefix('')->name('admin.')->namespace('App\Http\Controllers\Admin')->group(function () {

    Route::get('/', 'AdminAuthController@showLoginForm')->name('login');
    Route::post('login', 'AdminAuthController@login')->name('adminlogin');
    Route::get('logout', 'AdminAuthController@logout')->name('logoutAdmin');
    Route::get('/terms-privacy', 'AdminAuthController@privacy')->name('terms-privacy');
    Route::get('/contact-us', 'AdminAuthController@contactUs')->name('contact-us');
    Route::post('/contact-store', 'AdminAuthController@contactStore')->name('contactstore');
    Route::get('password/reset', function () {
        return view('admin.forget-password');
    })->name('password.request');

    Route::post('password/reset', 'PasswordResetController@sendResetLinkEmail')
        ->name('password.email');
    Route::middleware('admin')->group(function () {
        Route::get('dashboard', 'DashboardController@index')->name('dashboard');
        Route::get('profile', 'ProfileController@edit')->name('profile.edit');
        Route::patch('profile', 'ProfileController@update')->name('profile.update');
        Route::delete('profile', 'ProfileController@destroy')->name('profile.destroy');
        Route::get('changepassword', 'ProfileController@viewPassword')->name('change.password');
        Route::patch('changepassword', 'ProfileController@updatePassword')->name('password.update');

        //type management
        Route::get('type', 'TypeController@get')->name('type');
        Route::post('type/{id}', 'TypeController@delete')->name('typedelete');
        Route::post('type', 'TypeController@add')->name('type.add');
        Route::patch('type/edit/{id}', 'TypeController@update')->name('type.update');
        Route::get('type/{id}', 'TypeController@show')->name('type.show');

        //food type management
        Route::get('food-type', 'FoodTypeController@get')->name('food-type');
        Route::post('foodtype/{id}', 'FoodTypeController@delete')->name('foodtypedelete');
        Route::post('foodtype', 'FoodTypeController@add')->name('foodtype.add');
        Route::patch('foodtype/edit/{id}', 'FoodTypeController@update')->name('foodtype.update');
        Route::get('foodtype/{id}', 'FoodTypeController@show')->name('foodtype.show');


        //category management
        Route::get('category', 'CategoryController@get')->name('category');
        Route::post('category/{id}', 'CategoryController@delete')->name('categorydelete');
        Route::post('category', 'CategoryController@add')->name('category.add');
        Route::patch('category/edit/{id}', 'CategoryController@update')->name('category.update');
        Route::get('category/{id}', 'CategoryController@show')->name('category.show');
        //plan 
        Route::get('plan', 'PlanController@get')->name('plan');
        Route::post('plan/{id}', 'PlanController@delete')->name('plandelete');
        Route::post('plan', 'PlanController@add')->name('plan.add');
        Route::patch('plan/edit/{id}', 'PlanController@update')->name('plan.update');
        Route::get('plan/{id}', 'PlanController@show')->name('plan.show');
        Route::get('subscriptions-history', 'PlanController@getSubscriptions')->name('subscriptions.history');
        //user management
        Route::get('incoming/chef', 'UserAdminController@index')->name('incoming.user');
        Route::get('active/chef', 'UserAdminController@activeChef')->name('active.chef');
        Route::post('/users/block/{id}', 'UserAdminController@block')->name('users.block');
        Route::post('/users/unblock/{id}', 'UserAdminController@unblock')->name('users.unblock');
        Route::post('/users/accept/{id}', 'UserAdminController@accept')->name('users.accept');
        Route::post('/users/reject/{id}', 'UserAdminController@reject')->name('users.reject');
        Route::post('/users/{id}/toggle-featured','UserAdminController@toggleFeatured')->name('users.toggleFeatured');

        Route::get('/user-deatil/{id}', 'UserAdminController@show')->name('userdetail');
        Route::get('active/user', 'UserAdminController@activeUser')->name('active.user');
        Route::post('get-menu', 'UserAdminController@getMenu')->name('get-menu');
        Route::get('/get-content', 'DashboardController@getContent')->name('get-content');
        Route::post('/content', 'DashboardController@storeContent')->name('contentstore');
        Route::get('/contactus/list', 'DashboardController@contactusList')->name('contactusList');
        Route::post('/get-contact', 'DashboardController@getContact')->name('get-contact');
        Route::get('order', 'OrderController@index')->name('order.list');
        Route::get('/order-deatil/{id}', 'OrderController@show')->name('orderdetail');
        Route::get('report', 'OrderController@reportList')->name('report.list');
        Route::post('/get-report', 'OrderController@getreport')->name('get-report');

    });
});
